//  The MIT License (MIT)
//
//  Copyright © 2017 Saurabh Rane
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in all
//  copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//  SOFTWARE.

import UIKit
import SwiftIcons

class IconDetailViewController: UIViewController {
    
    var index: Int!
    var icon: FontType!
    var indexPath: IndexPath!
    
    @IBOutlet var name: UILabel!
    
    var iconColors = ["e74c3c", "e67e22", "f1c40f", "2ecc71", "1abc9c", "3498db", "9b59b6", "e4Accf", "95a5a6", "34495e", "6c6998", "00695C"]
    var fonts = ["DRIPICONS", "EMOJI", "FONT-AWESOME-REGULAR", "ICO FONT", "IONICONS", "LINEARICONS", "MAP-ICONS", "MATERIAL ICONS", "OPEN ICONIC", "STATE FACE", "WEATHER ICONS", "TYPICONS"]

    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        var icons = [[String]]()
        icons.append(dripIcons)
        icons.append(emojiIcons)
        icons.append(fontAwesomeRegularIcons)
        icons.append(icofontIcons)
        icons.append(ionicons)
        icons.append(linearicons)
        icons.append(mapicons)
        icons.append(googleMaterialDesignIcons)
        icons.append(openiconicIcons)
        icons.append(stateIcons)
        icons.append(weatherIcons)
        icons.append(typIcons)

        let color = UIColor.init(hex: iconColors[index!])
        let font = UIFont(name: "AppleSDGothicNeo-Bold", size: 20)
        let attributes = [NSAttributedString.Key.font : font!, NSAttributedString.Key.foregroundColor: color]
        
        navigationController?.navigationBar.titleTextAttributes = attributes
        navigationItem.title = fonts[index]
        navigationItem.leftBarButtonItem = UIBarButtonItem(title: "", style: .plain, target: self, action: #selector(goBack(sender:)))
        navigationItem.leftBarButtonItem?.setIcon(icon: .fontAwesomeSolid(.longArrowAltLeft), iconSize: 30, color: color)
        
        let screenSize = UIScreen.main.bounds
        let screenWidth = screenSize.width
        
        var length1: CGFloat = 0.0, length2: CGFloat = 0.0, length3: CGFloat = 0.0, length4: CGFloat = 0.0
        
        switch screenWidth {
        case 320:
            length1 = 100
            length2 = 80
            length3 = 50
            length4 = 30
        case 375:
            length1 = 120
            length2 = 90
            length3 = 55
            length4 = 35
        case 414:
            length1 = 150
            length2 = 100
            length3 = 60
            length4 = 40
        default:
            break
        }
        
        let total = length1 + length2 + length3 + length4
        let remaining = screenWidth - total
        let spacing = remaining/5
        let y: CGFloat = 80
        
        let lImage = UIImageView(frame: CGRect(x: spacing, y: y, width: length1, height: length1))
        lImage.setIcon(icon: icon, textColor: color, backgroundColor: .clear, size: nil)
        
        let mImage = UIImageView(frame: CGRect(x: 2*spacing + length1, y: y + (length1-length2)/2, width: length2, height: length2))
        mImage.setIcon(icon: icon, textColor: color, backgroundColor: .clear, size: nil)
        
        let sImage = UIImageView(frame: CGRect(x: 3*spacing + length1 + length2, y: y + (length1-length3)/2, width: length3, height: length3))
        sImage.setIcon(icon: icon, textColor: color, backgroundColor: .clear, size: nil)
        
        let xsImage = UIImageView(frame: CGRect(x: 4*spacing + length1 + length2 + length3, y: y + (length1-length4)/2, width: length4, height: length4))
        xsImage.setIcon(icon: icon, textColor: color, backgroundColor: .clear, size: nil)
        
        self.view.addSubview(lImage)
        self.view.addSubview(mImage)
        self.view.addSubview(sImage)
        self.view.addSubview(xsImage)
        
        name.adjustsFontSizeToFitWidth = true
        name.textColor = color
        name.text = icons[index][indexPath.row]
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    // MARK: - Naviga@objc tion
    
    @objc func goBack(sender: UIBarButtonItem) {
        _ = navigationController?.popViewController(animated: true)
    }

    /*
    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */
    
    let dripIcons = ["Alarm", "AlignCenter", "AlignJustify", "AlignLeft", "AlignRight", "Anchor", "Archieve", "ArrowDown", "ArrowLeft", "ArrowRight", "ArrowThinDown", "ArrowThinLeft", "ArrowThinRight", "ArrowThinUp", "ArrowUp", "Article", "Backspace", "Basket", "Basketball", "BatteryEmpty", "BatteryFull", "BatteryLow", "BatteryMedium", "Bell", "Blog", "Bluetooth", "Bold", "Bookmark", "Bookmarks", "Box", "Briefcase", "BrightnessLow", "BrightnessMax", "BrightnessMedium", "Broadcast", "Browser", "BrowserUpload", "Brush", "Calendar", "Camcorder", "Camera", "Card", "Cart", "Checklist", "Checkmark", "ChevronDown", "ChevronLeft", "ChevronRight", "ChevronUp", "Clipboard", "Clock", "Clockwise", "Cloud", "CloudDownload", "CloudUpload", "Code", "Contract", "Contract2", "Conversation", "Copy", "Crop", "Cross", "Crosshair", "Cutlery", "DeviceDesktop", "DeviceMobile", "DeviceTablet", "Direction", "Disc", "Document", "DocumentDelete", "DocumentEdit", "DocumentNew", "DocumentRemove", "Dot", "Dots2", "Dots3", "Download", "Duplicate", "Enter", "Exit", "Expand", "Expand2", "Experiment", "Export", "Feed", "Flag", "Flashlight", "Folder", "FolderOpen", "Forward", "Gaming", "Gear", "Graduation", "GraphBar", "GraphLine", "GraphPie", "Headset", "Heart", "Help", "Home", "Hourglass", "Inbox", "Information", "Italic", "Jewel", "Lifting", "Lightbulb", "Link", "LinkBroken", "List", "Loading", "Location", "Lock", "LockOpen", "Mail", "Map", "MediaLoop", "MediaNext", "MediaPause", "MediaPlay", "MediaPrevious", "MediaRecord", "MediaShuffle", "MediaStop", "Medical", "Menu", "Message", "Meter", "Microphone", "Minus", "Monitor", "Move", "Music", "Network1", "Network2", "Network3", "Network4", "Network5", "Pamphlet", "Paperclip", "Pencil", "Phone", "Photo", "PhotoGroup", "Pill", "Pin", "Plus", "Power", "Preview", "Print", "Pulse", "Question", "Reply", "ReplyAll", "ReturnIcon", "Retweet", "Rocket", "Scale", "Search", "ShoppingBag", "Skip", "Stack", "Star", "Stopwatch", "Store", "Suitcase", "Swap", "Tag", "TagDelete", "Tags", "ThumbsDown", "ThumbsUp", "Ticket", "TimeReverse", "ToDo", "Toggles", "Trash", "Trophy", "Upload", "User", "UserGroup", "UserId", "Vibrate", "ViewApps", "ViewList", "ViewListLarge", "ViewThumb", "VolumeFull", "VolumeLow", "VolumeMedium", "VolumeOff", "Wallet", "Warning", "Web", "Weight", "Wifi", "Wrong", "ZoomIn", "ZoomOut"]
    
    let emojiIcons = ["AceOfClubs", "AceOfDiamonds", "AceOfHearts", "AceOfSpades", "Addressbook", "Airplane", "Alarm", "Aleph", "Alien", "Ampersand", "Anchor", "AnimalAnt", "AnimalBactrianCamel", "AnimalBug", "AnimalCat", "AnimalCow", "AnimalDolphin", "AnimalDromedaryCamel", "AnimalGoat", "AnimalHorse", "AnimalPig", "AnimalRabbit", "AnimalRooster", "AnimalSnail", "Ankh", "Apple", "ArrowDown", "ArrowDownLeft", "ArrowDownRight", "ArrowForward", "ArrowLeft", "ArrowLeftRight", "ArrowRedo", "ArrowReply", "ArrowRight", "ArrowUndo", "ArrowUp", "ArrowUpDown", "ArrowUpLeft", "ArrowUpRight", "Asclepius", "AsteriskFive", "AsteriskSix", "At", "AtSymbol", "Atom", "Baby", "BabyBottle", "Backward", "Balloon", "Bank", "Banknote", "Baseball", "Battery", "Beach", "Bell", "Bicycle", "Bicyclist", "Billiards", "Biohazard", "BlackFlorette", "Bolt", "Bomb", "Book", "BookOpen", "Bookmark", "Books", "Bouquet", "Bowling", "BraceLeft", "BraceRight", "Bread", "Brightness", "BrowserChrome", "BrowserFirefox", "BrowserIe", "BrowserOpera", "BrowserSafari", "Building", "Bullhorn", "Bullseye", "Bus", "BusFront", "Cabinet", "Cactus", "Caduceus", "Cake", "Calculator", "CalendarDay", "CalendarMonth", "CameraMovie", "Cancel", "Candle", "Candy", "Car", "CarFront", "CaretDown", "CaretLeft", "CaretRight", "CaretUp", "Castle", "CelticCross", "Chair", "Chart", "ChartDown", "ChartLine", "ChartUp", "Check", "CheckboxChecked", "CheckboxPartial", "CheckboxUnchecked", "ChessBlackBishop", "ChessBlackKing", "ChessBlackKnight", "ChessBlackPawn", "ChessBlackQueen", "ChessBlackRook", "ChessWhiteBishop", "ChessWhiteKing", "ChessWhiteKnight", "ChessWhitePawn", "ChessWhiteQueen", "ChessWhiteRook", "Chessboard", "ChiRho", "ChickenLeg", "ChristmasTree", "Church", "Cinema", "Circle", "CircleArrowDown", "CircleArrowLeft", "CircleArrowRight", "CircleArrowUp", "CircleOpen", "Circus", "Clipboard", "Clock", "Close", "Cloud", "Clubs", "Coffin", "Comet", "Command", "ComputerNetwork", "ConstructionWorker", "Contrast", "ConvenienceStore", "Cooking", "Copy", "Copyright", "Creditcard", "CrossOfJerusalem", "CrossOfLorraine", "CrossOrthodox", "CrossPommee", "CrossedSwords", "Crosshairs", "Crown", "CurrencyDollar", "CurrencyEuro", "CurrencyExchange", "CurrencyPound", "Dagger", "Dancing", "Database", "Death", "Diamond", "Diamonds", "Die", "Digg", "DigitEight", "DigitFive", "DigitFour", "DigitNine", "DigitOne", "DigitSeven", "DigitSix", "DigitThree", "DigitTwo", "DigitZero", "Disk", "Divide", "Dna", "Donut", "DrinkBeer", "DrinkCocktail", "DrinkCoffee", "DrinkTropical", "DrinkWine", "Droplet", "Ear", "Eject", "ElectricCord", "Enter", "Envelope", "EnvelopeStamped", "ExclamationMark", "Explosion", "Eye", "Eyeglasses", "FaceBaby", "FaceBear", "FaceBoy", "FaceCallcenter", "FaceChihuahua", "FaceGirl", "FaceHamster", "FaceKitty", "FaceMan", "FaceManWithTurban", "FaceMonkey", "FaceOldChineseMan", "FacePrincess", "FaceSantaClaus", "FaceWoman", "Factory", "Family", "Farsi", "FerrisWheel", "File", "FileImage", "FileText", "Film", "FilmReel", "Fire", "Fireworks", "First", "Flag", "FlagCheckered", "FlagOpen", "Flashlight", "FleurDeLis", "Floppy", "Florette", "Flower", "Folder", "FolderOpen", "FontSize", "FoodChicken", "FoodHamburger", "FoodIceCream", "FoodPizza", "FoodRice", "FoodSpaghetti", "FootballAmerican", "FootballSoccer", "Footprints", "Forbidden", "ForkKnife", "ForkKnifePlate", "Forward", "Fountain", "FourCorners", "FourLeafClover", "Fries", "FuelPump", "GClef", "GarbageCan", "Gear", "GearNoHub", "GenderFemale", "GenderFemaleFemale", "GenderMale", "GenderMaleFemale", "GenderMaleMale", "GenderNonBinary", "GenderTransgender", "Ghost", "Gift", "Gingerbread", "Globe2", "GlobeMeridians", "Graduation", "Grapes", "GuardIcon", "Guitar", "Hammer", "HammerAndPick", "HammerSickle", "HammerWrench", "Hand", "HandFist", "Handbag", "HardDisk", "Headphone", "Headstone", "Heart", "HeartBeating", "HeartBroken", "HeartOpen", "HeartRibbon", "HeartTilted", "HeartWithArrow", "Hearts", "Helm", "Herb", "Hexagon", "HighHeeledShoes", "Home", "Hotel", "Hourglass", "IceSkater", "Imp", "Inbox", "Infinity", "JackOLantern", "Joystick", "Key", "KeyAlt", "Keyboard", "KeyboardWireless", "Khanda", "Kiss", "Knife", "Label", "Laptop", "Last", "Lastfm", "LatinCross", "LatinCrossOutline", "Leaf", "LeftLuggage", "Lemon", "LetterA", "LetterB", "LetterC", "LetterD", "LetterE", "LetterF", "LetterG", "LetterH", "LetterI", "LetterJ", "LetterK", "LetterL", "LetterM", "LetterN", "LetterO", "LetterP", "LetterQ", "LetterR", "LetterS", "LetterT", "LetterU", "LetterV", "LetterW", "LetterX", "LetterY", "LetterZ", "Lightbulb", "Link", "Linux", "Lipstick", "Lock", "LockOpen", "Lollipop", "Loop", "LoopAlt", "MalteseCross", "ManAndMan", "ManAndWoman", "MapleLeaf", "MaximizeWindow", "MedalMilitary", "MedalSports", "Menu", "Microphone", "Microscope", "Minimize", "Minus", "MoneyBag", "Monitor", "MoonFirstQuarter", "MoonFull", "MoonLastQuarter", "MoonNew", "MoonWaningCrescent", "MoonWaningGibbous", "MoonWaxingCrescent", "MoonWaxingGibbous", "Motorbike", "Mouse", "Movie", "Multiply", "Mushroom", "MusicEighthNote", "MusicEigthNotes", "MusicPlayer", "MusicQuarterNote", "MusicSixteenthNotes", "MusicTrumpet", "MusicViolin", "Newspaper", "NextPage", "NoEntry", "Notebook", "Notepad", "Number", "NutAndBolt", "Om", "Omega", "OsAndroid", "OsApple", "OsWindows", "Outbox", "OutfitBikini", "OutfitDress", "OutfitNecktie", "OutfitShirt", "Pager", "Palette", "Panda", "Paperclip", "ParenthesisLeft", "ParenthesisRight", "PassportControl", "Pause", "PawPrints", "PcDesktop", "PcOld", "Peace", "PeaceDove", "Pear", "Pedestrian", "Pen", "Pencil", "Pentagon", "Pentagram", "PentagramInverted", "Percent", "PerformingArts", "PermanentPaper", "Perthousand", "Phone", "PhoneLocation", "PhoneMobile", "PhoneReceiver", "PhotoCamera", "PhotoCameraFlash", "Piano", "Pick", "Picture", "PieChart", "PieChartReverse", "Pill", "Pistol", "Play", "Plus", "PointDown", "PointLeft", "PointRight", "PointUp", "PotFood", "PreviousPage", "PrintScreen", "Printer", "Projector", "Purse", "Pushpin", "QuestionMark", "Radiation", "Radio", "RadioChecked", "Rainbow", "Record", "Recycle", "Registered", "Restroom", "Retrograde", "RiceBall", "Ring", "Rocket", "Rollercoaster", "RotateCcw", "RotateCcwSide", "RotateCw", "RotateCwSide", "Ruler", "Ruler2", "Running", "Sandals", "SatelliteDisk", "Saxophone", "Scales", "School", "Scissors", "SearchLeft", "SearchRight", "Shamrock", "Shield", "ShieldWithCross", "Shuffle", "Skier", "Skull", "SkullAndBones", "SlotMachine", "Smiley", "SmileyCool", "SmileyEvil", "SmileyGrin", "SmileyHappy", "SmileySad", "Smoking", "SmokingForbidden", "Snake", "Snowboarding", "Snowflake", "Snowman", "Spades", "SpeechBubble", "Spider", "Spider7Web", "Spy", "Square", "SquareBracketLeft", "SquareBracketRight", "SquareMinus", "SquarePlus", "StackWindow", "Star", "StarAndCrescent", "StarCircled", "StarEightPoints", "StarOfDavid", "StarOpen", "StarShooting", "SteamingBowl", "Stop", "Stopwatch", "Suitcase", "Sun", "Sunglasses", "Sushi", "SwastikaLeft", "SwastikaRight", "Swimming", "Syringe", "Tao", "Tape", "Target", "Telescope", "Television", "Temple", "Tennis", "Tent", "ThumbsDown", "ThumbsUp", "Ticket", "Tomato3", "Tophat", "TrafficLight", "Tree", "TreePalm", "TreePine", "Trophy", "Truck", "Umbrella", "User", "Users", "VideoCamera", "Videogame", "Vk", "Volume", "VolumeHigh", "VolumeLow", "VolumeMute", "Warning", "Watch", "WaterWave", "WebBehance", "WebBlogger", "WebCircles", "WebDelicious", "WebDeviantart", "WebDribbble", "WebDropbox", "WebDrupal", "WebEvernote", "WebFacebook", "WebFlattr", "WebFlickr", "WebForrst", "WebFoursquare", "WebGit", "WebGithub", "WebGoogleDrive", "WebGoogleplus", "WebInstagram", "WebJoomla", "WebLastfm", "WebLinkedin", "WebMixi", "WebPaypal", "WebPicasa", "WebPicassa", "WebPinterest", "WebQq", "WebRdio", "WebReddit", "WebRenren", "WebSinaWeibo", "WebSkype", "WebSmashing", "WebSoundcloud", "WebSpotify", "WebStackoverflow", "WebSteam", "WebStumbleupon", "WebTumblr", "WebTwitter", "WebVimeo", "WebVine", "WebVk", "WebWordpress", "WebYelp", "Weighlifting", "WheelOfDharma", "Wheelchair", "WomanAndWoman", "WorldMap", "Wrench", "Yen", "Youtube"]

    let fontAwesomeRegularIcons = ["addressBook", " addressCard", " angry", " arrowAltCircleDown", " arrowAltCircleLeft", " arrowAltCircleRight", " arrowAltCircleUp", " bell", " bellSlash", " bookmark", " building", " calendar", " calendarAlt", " calendarCheck", " calendarMinus", " calendarPlus", " calendarTimes", " caretSquareDown", " caretSquareLeft", " caretSquareRight", " caretSquareUp", " chartBar", " checkCircle", " checkSquare", " circle", " clipboard", " clock", " clone", " closedCaptioning", " comment", " commentAlt", " commentDots", " comments", " compass", " copy", " copyright", " creditCard", " dizzy", " dotCircle", " edit", " envelope", " envelopeOpen", " eye", " eyeSlash", " file", " fileAlt", " fileArchive", " fileAudio", " fileCode", " fileExcel", " fileImage", " filePdf", " filePowerpoint", " fileVideo", " fileWord", " flag", " flushed", " folder", " folderOpen", " fontAwesomeLogoFull", " frown", " frownOpen", " futbol", " gem", " grimace", " grin", " grinAlt", " grinBeam", " grinBeamSweat", " grinHearts", " grinSquint", " grinSquintTears", " grinStars", " grinTears", " grinTongue", " grinTongueSquint", " grinTongueWink", " grinWink", " handLizard", " handPaper", " handPeace", " handPointDown", " handPointLeft", " handPointRight", " handPointUp", " handPointer", " handRock", " handScissors", " handSpock", " handshake", " hdd", " heart", " hospital", " hourglass", " idBadge", " idCard", " image", " images", " keyboard", " kiss", " kissBeam", " kissWinkHeart", " laugh", " laughBeam", " laughSquint", " laughWink", " lemon", " lifeRing", " lightbulb", " listAlt", " map", " meh", " mehBlank", " mehRollingEyes", " minusSquare", " moneyBillAlt", " moon", " newspaper", " objectGroup", " objectUngroup", " paperPlane", " pauseCircle", " playCircle", " plusSquare", " questionCircle", " registered", " sadCry", " sadTear", " save", " shareSquare", " smile", " smileBeam", " smileWink", " snowflake", " square", " star", " starHalf", " stickyNote", " stopCircle", " sun", " surprise", " thumbsDown", " thumbsUp", " timesCircle", " tired", " trashAlt", " user", " userCircle", " windowClose", " windowMaximize", " windowMinimize", " windowRestore"]

    let ionicons = ["Alert", "AlertCircled", "AndroidAdd", "AndroidAddCircle", "AndroidAlarmClock", "AndroidAlert", "AndroidApps", "AndroidArchive", "AndroidArrowBack", "AndroidArrowDown", "AndroidArrowDropdown", "AndroidArrowDropdownCircle", "AndroidArrowDroplet", "AndroidArrowDropletCircle", "AndroidArrowDropright", "AndroidArrowDroprightCircle", "AndroidDropup", "AndroidDropupCircle", "AndroidArrowForward", "AndroidArrowUp", "AndroidAttach", "AndroidBar", "AndroidBicycle", "AndroidBoat", "AndroidBookmark", "AndroidBulb", "AndroidBus", "AndroidCalendar", "AndroidCall", "AndroidCamera", "AndroidCancel", "AndroidCar", "AndroidCart", "AndroidChat", "AndroidCheckbox", "AndroidCheckboxBlank", "AndroidCheckboxOutline", "AndroidCheckboxOutlineBlank", "AndroidCheckmarkCircle", "AndroidClipboard", "AndroidClose", "AndroidCloud", "AndroidCloudCircle", "AndroidCloudDone", "AndroidCloudOutline", "AndroidColorPalette", "AndroidCompass", "AndroidContact", "AndroidContacts", "AndroidContract", "AndroidCreate", "AndroidDelete", "AndroidDesktop", "AndroidDocument", "AndroidDone", "AndroidDoneAll", "AndroidDownload", "AndroidDrafts", "AndroidExit", "AndroidExpand", "AndroidFavorite", "AndroidFavoriteOutline", "AndroidFilm", "AndroidFolder", "AndroidFolderOpen", "AndroidFunnel", "AndroidGlobe", "AndroidHand", "AndroidHangout", "AndroidHappy", "AndroidHome", "AndroidImage", "AndroidLaptop", "AndroidList", "AndroidLocate", "AndroidLock", "AndroidMail", "AndroidMap", "AndroidMenu", "AndroidMicrophone", "AndroidMicrophoneOff", "AndroidMoreHorizontal", "AndroidMoreVertical", "AndroidNavigate", "AndroidNotifications", "AndroidNotificationsNone", "AndroidNotificationsOff", "AndroidOpen", "AndroidOptions", "AndroidPeople", "AndroidPerson", "AndroidPersonAdd", "AndroidPhoneLandscape", "AndroidPhonePortrait", "AndroidPin", "AndroidPlane", "AndroidPlaystore", "AndroidPrint", "AndroidRadioButtonOff", "AndroidRadioButtonOn", "AndroidRefresh", "AndroidRemove", "AndroidRemoveCircle", "AndroidRestaurant", "AndroidSad", "AndroidSearch", "AndroidSend", "AndroidSettings", "AndroidShare", "AndroidShareAlt", "AndroidStar", "AndroidStarHalf", "AndroidStarOutline", "AndroidStopwatch", "AndroidSubway", "AndroidSunny", "AndroidSync", "AndroidTextsms", "AndroidTime", "AndroidTrain", "AndroidUnlock", "AndroidUpload", "AndroidVolumeDown", "AndroidVolumeMute", "AndroidVolumeOff", "AndroidVolumeUp", "AndroidWalk", "AndroidWarning", "AndroidWatch", "AndroidWifi", "Aperture", "Archive", "ArrowDownA", "ArrowDownB", "ArrowDownC", "ArrowExpand", "ArrowGraphDownLeft", "ArrowGraphDownRight", "ArrowGraphUpLeft", "ArrowGraphUpRight", "ArrowLeftA", "ArrowLeftB", "ArrowLeftC", "ArrowMove", "ArrowResize", "ArrowReturnLeft", "ArrowReturnRight", "ArrowRightA", "ArrowRightB", "ArrowRightC", "ArrowShrink", "ArrowSwap", "ArrowUpA", "ArrowUpB", "ArrowUpC", "Asterisk", "At", "Backspace", "BackspaceOutline", "Bag", "BatteryCharging", "BatteryEmpty", "BatteryFull", "BatteryHalf", "BatteryLow", "Beaker", "Beer", "Bluetooth", "Bonfire", "Bookmark", "Bowtie", "Briefcase", "Bug", "Calculator", "Calendar", "Camera", "Card", "Cash", "Chatbox", "ChatboxWorking", "Chatboxes", "Chatbubble", "ChatbubbleWorking", "Chatbubbles", "Checkmark", "CheckmarkCircled", "CheckmarkRound", "ChevronDown", "ChevronLeft", "ChevronRight", "ChevronUp", "Clipboard", "Clock", "Close", "CloseCircled", "CloseRound", "ClosedCaptioning", "Cloud", "Code", "CodeDownload", "CodeWorking", "Coffee", "Compass", "Compose", "ConnectionBars", "Contrast", "Crop", "Cube", "Disc", "Document", "DocumentText", "Drag", "Earth", "Easel", "Edit", "Egg", "Eject", "Email", "EmailUnread", "ErlenmeyerFlask", "ErlenmeyerFlaskBubbles", "Eye", "EyeDisabled", "Female", "Filing", "FilmMaker", "Fireball", "Flag", "Flame", "Flash", "FlashOff", "Folder", "Fork", "ForkRepo", "Forward", "Funnel", "GearA", "GearB", "Grid", "Hammer", "Happy", "HappyOutline", "Headphone", "Heart", "HeartBroken", "Help", "HelpBuoy", "HelpCircled", "Home", "Icecream", "Image", "Images", "Information", "InformationCircled", "Ionic", "IosAlarm", "IosAlarmOutline", "IosAlbums", "IosAlbumsOutline", "IosAmericanfootball", "IosAmericanfootballOutline", "IosAnalytics", "IosAnalyticsOutline", "IosArrowBack", "IosArrowDown", "IosArrowForward", "IosArrowLeft", "IosArrowRight", "IosArrowThinDown", "IosArrowThinLeft", "IosArrowThinRight", "IosArrowThinUp", "IosArrowUp", "IosAt", "IosAtOutline", "IosBarcode", "IosBarcodeOutline", "IosBaseball", "IosBaseballOutline", "IosBasketball", "IosBasketBallOutline", "IosBell", "IosBellOutline", "IosBody", "IosBodyOutline", "IosBolt", "IosBoltOutline", "IosBook", "IosBookOutline", "IosBookmarks", "IosBookmarksOutline", "IosBox", "IosBoxOutline", "IosBriefcase", "IosBriefcaseOutline", "IosBrowsers", "IosBrowsersOutline", "IosCalculator", "IosCalculatorOutline", "IosCalendar", "IosCalendarOutline", "IosCamera", "IosCameraOutline", "IosCart", "IosCartOutline", "IosChatboxes", "IosChatboxesOutline", "IosChatbubble", "IosChatbubbleOutline", "IosCheckmark", "IosCheckmarkEmpty", "IosCheckmarkOutline", "IosCircleFilled", "IosCircleOutline", "IosClock", "IosClockOutline", "IosClose", "IosCloseEmpty", "IosCloseOutline", "IosCloud", "IosCloudDownload", "IosCloudDownloadOutline", "IosCloudOutline", "IosCloudUpload", "IosCloudUploadOutline", "IosCloudy", "IosCloudyNight", "IosCloudyNightOutline", "IosCloudyOutline", "IosCog", "IosCogOutline", "IosColorFilter", "IosColorFilterOutline", "IosColorWand", "IosColorWandOutline", "IosCompose", "IosComposeOutline", "IosContact", "IosContactOutline", "IosCopy", "IosCopyOutline", "IosCrop", "IosCropStrong", "IosDownload", "IosDownloadOutline", "IosDrag", "IosEmail", "IosEmailOutline", "IosEye", "IosEyeOutline", "IosFastforward", "IosFastforwardOutline", "IosFiling", "IosFilingOutline", "IosFilm", "IosFilmOutline", "IosFlag", "IosFlagOutline", "IosFlame", "IosFlameOutline", "IosFlask", "IosFlaskOutline", "IosFlower", "IosFlowerOutline", "IosFolder", "IosFolderOutline", "IosFootball", "IosFootballOutline", "IosGameControllerA", "IosGameControllerAOutline", "IosGameControllerB", "IosGameControllerBOutline", "IosGear", "IosGearOutline", "IosGlasses", "IosGlassesOutline", "IosGridView", "IosGridViewOutline", "IosHeart", "IosHeartOutline", "IosHelp", "IosHelpEmpty", "IosHelpOutline", "IosHome", "IosHomeOutline", "IosInfinite", "IosInfiniteOutline", "IosInformation", "IosInformationEmpty", "IosInformationOutline", "IosIonicOutline", "IosKeypad", "IosKeypadOutline", "IosLightbulb", "IosLightbulbOutline", "IosList", "IosListOutline", "IosLocation", "IosLocationOutline", "IosLocked", "IosLockedOutline", "IosLoop", "IosLoopStrong", "IosMedical", "IosMedicalOutline", "IosMedkit", "IosMedkitOutline", "IosMic", "IosMicOff", "IosMicOutline", "IosMinus", "IosMinusEmpty", "IosMinusOutline", "IosMonitor", "IosMonitorOutline", "IosMoon", "IosMoonOutline", "IosMore", "IosMoreOutline", "IosMusicalNote", "IosMusicalNotes", "IosNavigate", "IosNavigateOutline", "IosNutrition", "IosNutritionOutline", "IosPaper", "IosPaperOutline", "IosPaperplane", "IosPaperplaneOutline", "IosPartlySunny", "IosPartlySunnyOutline", "IosPause", "IosPauseOutline", "IosPaw", "IosPawOutline", "IosPeople", "IosPeopleOutline", "IosPerson", "IosPersonOutline", "IosPersonadd", "IosPersonaddOutline", "IosPhotos", "IosPhotosOutline", "IosPie", "IosPieOutline", "IosPint", "IosPintOutline", "IosPlay", "IosPlayOutline", "IosPlus", "IosPlusEmpty", "IosPlusOutline", "IosPricetag", "IosPricetagOutline", "IosPricetags", "IosPricetagsOutline", "IosPrinter", "IosPrinterOutline", "IosPulse", "IosPulseStrong", "IosRainy", "IosRainyOutline", "IosRecording", "IosRecordingOutline", "IosRedo", "IosRedoOutline", "IosRefresh", "IosRefreshEmpty", "IosRefreshOutline", "IosReload", "IosReverseCamera", "IosReverseCameraOutline", "IosReward", "IosRewardOutline", "IosRose", "IosRoseOutline", "IosSearch", "IosSearchStrong", "IosSettings", "IosSettingsStrong", "IosShuffle", "IosShuffleStrong", "IosSkipbackward", "IosSkipbackwardOutline", "IosSkipforward", "IosSkipforwardOutline", "IosSnowy", "IosSpeedometer", "IosSpeedometerOutline", "IosStar", "IosStarHalf", "IosStarOutline", "IosStopwatch", "IosStopwatchOutline", "IosSunny", "IosSunnyOutline", "IosTelephone", "IosTelephoneOutline", "IosTennisball", "IosTennisballOutline", "IosThunderstorm", "IosThunderstormOutline", "IosTime", "IosTimeOutline", "IosTimer", "IosTimerOutline", "IosToggle", "IosToggleOutline", "IosTrash", "IosTrashOutline", "IosUndo", "IosUndoOutline", "IosUnlocked", "IosUnlockedOutline", "IosUpload", "IosUploadOutline", "IosVideocam", "IosVideocamOutline", "IosVolumeHigh", "IosVolumeLow", "IosWineglass", "IosWineglassOutline", "IosWorld", "IosWorldOutline", "Ipad", "Iphone", "Ipod", "Jet", "Key", "Knife", "Laptop", "Leaf", "Levels", "Lightbulb", "Link", "LoadA", "LoadB", "LoadC", "LoadD", "Location", "LockCombination", "Locked", "LogIn", "LogOut", "Loop", "Magnet", "Male", "Man", "Map", "Medkit", "Merge", "MicA", "MicB", "MicC", "Minus", "MinusCircled", "MinusRound", "ModelS", "Monitor", "More", "Mouse", "MusicNote", "Navicon", "NaviconRound", "Navigate", "Network", "NoSmoking", "Nuclear", "Outlet", "Paintbrush", "Paintbucket", "PaperAirplane", "Paperclip", "Pause", "Person", "PersonAdd", "PersonStalker", "PieGraph", "Pin", "Pinpoint", "Pizza", "Plane", "Planet", "Play", "Playstation", "Plus", "PlusCircled", "PlusRound", "Podium", "Pound", "Power", "Pricetag", "Pricetags", "Printer", "PullRequest", "QrScanner", "Quote", "RadioWaves", "Record", "Refresh", "Reply", "ReplyAll", "RibbonA", "RibbonB", "Sad", "SadOutline", "Scissors", "Search", "Settings", "Share", "Shuffle", "SkipBackward", "SkipForward", "SocialAndroid", "SocialAndroidOutline", "SocialAngular", "SocialAngularOutline", "SocialApple", "SocialAppleOutline", "SocialBitcoin", "SocialBitcoinOutline", "SocialBuffer", "SocialBufferOutline", "SocialChrome", "SocialChromeOutline", "SocialCodepan", "SocialCodepanOutline", "SocialCss3", "SocialCss3Outline", "SocialDesignernews", "SocialDesignernewsOutline", "SocialDribble", "SocialDribbleOutline", "SocialDropbox", "SocialDropboxOutline", "SocialEuro", "SocialEuroOutline", "SocialFacebook", "SocialFacebookOutline", "SocialFoursquare", "SocialFoursquareOutline", "SocialFreebsdDevil", "SocialGithub", "SocialGithubOutline", "SocialGoogle", "SocialGoogleOutline", "SocialGoogleplus", "SocialGoogleplusOutline", "SocialHackernews", "SocialHackernewsOutline", "SocialHtml5", "SocialHtml5Outline", "SocialInstagram", "SocialInstagramOutline", "SocialJavascript", "SocialJavascriptOutline", "SocialLinkedin", "SocialLinkedinOutline", "SocialMarkdown", "SocialNodejs", "SocialOctacat", "SocialPinterest", "SocialPinterestOutline", "SocialPython", "SocialReddit", "SocialRedditOutline", "SocialRss", "SocialRssOutline", "SocialSass", "SocialSkype", "SocialSkypeOutline", "SocialSnapchat", "SocialSnapchatOutline", "SocialTumblr", "SocialTumblrOutline", "SocialTux", "SocialTwitch", "SocialTwitchOutline", "SocialTwitter", "SocialTwitterOutline", "SocialUsd", "SocialUsdOutline", "SocialVimeo", "SocialVimeoOutline", "SocialWhatsapp", "SocialWhatsappOutline", "SocialWindows", "SocialWindowsOutline", "SocialWordpress", "SocialWordpressOutline", "SocialYahoo", "SocialYahooOutline", "SocialYen", "SocialYenOutline", "SocialYoutube", "SocialYoutubeOutline", "SoupCan", "SoupCanOutline", "Speakerphone", "Speedometer", "Spoon", "Star", "StatsBars", "Steam", "Stop", "Thermometer", "Thumbsdown", "Thumbsup", "Toggle", "ToggleFilled", "Transgender", "TrashA", "TrashB", "Trophy", "Tshirt", "TshirtOutline", "Umbrella", "University", "Unlocked", "Upload", "Usb", "Videocamera", "VolumeHigh", "VolumeLow", "VolumeMedium", "VolumeMute", "Wand", "Waterdrop", "Wifi", "Wineglass", "Woman", "Wrench", "Xbox"]
    
    let linearicons = ["Alarm", "Apartment", "ArrowDown", "ArrowDownCircle", "ArrowLeft", "ArrowLeftCircle", "ArrowRight", "ArrowRightCircle", "ArrowUp", "ArrowUpCircle", "Bicycle", "Bold", "Book", "Bookmark", "Briefcase", "Bubble", "Bug", "Bullhorn", "Bus", "CalendarFull", "Camera", "CameraVideo", "Car", "Cart", "ChartBars", "CheckmarkCircle", "ChevronDown", "ChevronDownCircle", "ChevronLeft", "ChevronLeftCircle", "ChevronRight", "ChevronRightCircle", "ChevronUp", "ChevronUpCircle", "CircleMinus", "Clock", "Cloud", "CloudCheck", "CloudDownload", "CloudSync", "CloudUpload", "Code", "CoffeeCup", "Cog", "Construction", "Crop", "Cross", "CrossCircle", "Database", "Diamond", "Dice", "Dinner", "DirectionLtr", "DirectionRtl", "Download", "Drop", "Earth", "Enter", "EnterDown", "Envelope", "Exit", "ExitUp", "Eye", "FileAdd", "FileEmpty", "FilmPlay", "Flag", "FrameContract", "FrameExpand", "Funnel", "Gift", "GraduationHat", "Hand", "Heart", "HeartPulse", "Highlight", "History", "Home", "Hourglass", "Inbox", "IndentDecrease", "IndentIncrease", "Italic", "Keyboard", "Laptop", "LaptopPhone", "Layers", "Leaf", "License", "Lighter", "LineSpacing", "Linearicons", "Link", "List", "Location", "Lock", "MagicWand", "Magnifier", "Map", "MapMarker", "Menu", "MenuCircle", "Mic", "Moon", "Move", "MusicNote", "Mustache", "Neutral", "PageBreak", "Paperclip", "Paw", "Pencil", "Phone", "PhoneHandset", "Picture", "PieChart", "Pilcrow", "PlusCircle", "PointerDown", "PointerLeft", "PointerRight", "PointerUp", "Poop", "PowerSwitch", "Printer", "Pushpin", "QuestionCircle", "Redo", "Rocket", "Sad", "Screen", "Select", "Shirt", "Smartphone", "Smile", "SortAlphaAsc", "SortAmountAsc", "SpellCheck", "Star", "StarEmpty", "StarHalf", "Store", "Strikethrough", "Sun", "Sync", "Tablet", "Tag", "TextAlignCenter", "TextAlignJustify", "TextAlignLeft", "TextAlignRight", "TextFormat", "TextFormatRemove", "TextSize", "ThumbsDown", "ThumbsUp", "Train", "Trash", "Underline", "Undo", "Unlink", "Upload", "User", "Users", "Volume", "VolumeHigh", "VolumeLow", "VolumeMedium", "Warning", "Wheelchair"]
    
    let mapicons = ["Abseiling", "Accounting", "Airport", "AmusementPark", "Aquarium", "Archery", "ArtGallery", "AssistiveListeningSystem", "Atm", "AudioDescription", "Bakery", "Bank", "Bar", "Baseball", "BeautySalon", "BicycleStore", "Bicycling", "BoatRamp", "BoatTour", "Boating", "BookStore", "BowlingAlley", "Braille", "BusStation", "Cafe", "Campground", "Canoe", "CarDealer", "CarRental", "CarRepair", "CarWash", "Casino", "Cemetery", "Chairlift", "Church", "Circle", "CityHall", "Climbing", "ClosedCaptioning", "ClothingStore", "Compass", "ConvenienceStore", "Courthouse", "CrossCountrySkiing", "Crosshairs", "Dentist", "DepartmentStore", "Diving", "Doctor", "Electrician", "ElectronicsStore", "Embassy", "Expand", "Female", "Finance", "FireStation", "FishCleaning", "Fishing", "FishingPier", "Florist", "Food", "Fullscreen", "FuneralHome", "FurnitureStore", "GasStation", "GeneralContractor", "Golf", "GroceryOrSupermarket", "Gym", "HairCare", "HangGliding", "HardwareStore", "Health", "HinduTemple", "HorseRiding", "Hospital", "IceFishing", "IceSkating", "InlineSkating", "InsuranceAgency", "JetSkiing", "JewelryStore", "Kayaking", "Laundry", "Lawyer", "Library", "LiquorStore", "LocalGovernment", "LocationArrow", "Locksmith", "Lodging", "LowVisionAccess", "Male", "MapPin", "Marina", "Mosque", "MotobikeTrail", "MovieRental", "MovieTheater", "MovingCompany", "Museum", "NaturalFeature", "NightClub", "OpenCaptioning", "Painter", "Park", "Parking", "PetStore", "Pharmacy", "Physiotherapist", "PlaceOfWorship", "Playground", "Plumber", "PointOfInterest", "Police", "Political", "PostBox", "PostOffice", "PostalCode", "PostalCodePrefix", "Rafting", "RealEstateAgency", "Restaurant", "RoofingContractor", "Route", "RoutePin", "RvPark", "Sailing", "School", "ScubaDiving", "Search", "Shield", "ShoppingMall", "SignLanguage", "Skateboarding", "SkiJumping", "Skiing", "Sledding", "Snow", "SnowShoeing", "Snowboarding", "Snowmobile", "Spa", "Square", "SquarePin", "SquareRounded", "Stadium", "Storage", "Store", "SubwayStation", "Surfing", "Swimming", "Synagogue", "TaxiStand", "Tennis", "Toilet", "TrailWalking", "TrainStation", "TransitStation", "TravelAgency", "Unisex", "University", "VeterinaryCare", "Viewing", "VolumeControlTelephone", "Walking", "Waterskiing", "WhaleWatching", "Wheelchair", "WindSurfing", "Zoo", "ZoomIn", "ZoomInAlt", "ZoomOut", "ZoomOutAlt"]
    
    let googleMaterialDesignIcons = ["AcUnit", "AccessAlarm", "AccessAlarms", "AccessTime", "Accessibility", "Accessible", "AccountBalance", "AccountBalanceWallet", "AccountBox", "AccountCircle", "Adb", "Add", "AddAPhoto", "AddAlarm", "AddAlert", "AddBox", "AddCircle", "AddCircleOutline", "AddLocation", "AddShoppingCart", "AddToPhotos", "AddToQueue", "Adjust", "AirlineSeatFlat", "AirlineSeatFlatAngled", "AirlineSeatIndividualSuite", "AirlineSeatLegroomExtra", "AirlineSeatLegroomNormal", "AirlineSeatLegroomReduced", "AirlineSeatReclineExtra", "AirlineSeatReclineNormal", "AirplanemodeActive", "AirplanemodeInactive", "Airplay", "AirportShuttle", "Alarm", "AlarmAdd", "AlarmOff", "AlarmOn", "Album", "AllInclusive", "AllOut", "Android", "Announcement", "Apps", "Archive", "ArrowBack", "ArrowDownward", "ArrowDropDown", "ArrowDropDownCircle", "ArrowDropUp", "ArrowForward", "ArrowUpward", "ArtTrack", "AspectRatio", "Assessment", "Assignment", "AssignmentInd", "AssignmentLate", "AssignmentReturn", "AssignmentReturned", "AssignmentTurnedIn", "Assistant", "AssistantPhoto", "AttachFile", "AttachMoney", "Attachment", "Audiotrack", "Autorenew", "AvTimer", "Backspace", "Backup", "BatteryAlert", "BatteryChargingFull", "BatteryFull", "BatteryStd", "BatteryUnknown", "BeachAccess", "Beenhere", "Block", "Bluetooth", "BluetoothAudio", "BluetoothConnected", "BluetoothDisabled", "BluetoothSearching", "BlurCircular", "BlurLinear", "BlurOff", "BlurOn", "Book", "Bookmark", "BookmarkBorder", "BorderAll", "BorderBottom", "BorderClear", "BorderColor", "BorderHorizontal", "BorderInner", "BorderLeft", "BorderOuter", "BorderRight", "BorderStyle", "BorderTop", "BorderVertical", "BrandingWatermark", "Brightness1", "Brightness2", "Brightness3", "Brightness4", "Brightness5", "Brightness6", "Brightness7", "BrightnessAuto", "BrightnessHigh", "BrightnessLow", "BrightnessMedium", "BrokenImage", "Brush", "BubbleChart", "BugReport", "Build", "BurstMode", "Business", "BusinessCenter", "Cached", "Cake", "Call", "CallEnd", "CallMade", "CallMerge", "CallMissed", "CallMissedOutgoing", "CallReceived", "CallSplit", "CallToAction", "Camera", "CameraAlt", "CameraEnhance", "CameraFront", "CameraRear", "CameraRoll", "Cancel", "CardGiftcard", "CardMembership", "CardTravel", "Casino", "Cast", "CastConnected", "CenterFocusStrong", "CenterFocusWeak", "ChangeHistory", "Chat", "ChatBubble", "ChatBubbleOutline", "Check", "CheckBox", "CheckBoxOutlineBlank", "CheckCircle", "ChevronLeft", "ChevronRight", "ChildCare", "ChildFriendly", "ChromeReaderMode", "ClassIcon", "Clear", "ClearAll", "Close", "ClosedCaption", "Cloud", "CloudCircle", "CloudDone", "CloudDownload", "CloudOff", "CloudQueue", "CloudUpload", "Code", "Collections", "CollectionsBookmark", "ColorLens", "Colorize", "Comment", "Compare", "CompareArrows", "Computer", "ConfirmationNumber", "ContactMail", "ContactPhone", "Contacts", "ContentCopy", "ContentCut", "ContentPaste", "ControlPoint", "ControlPointDuplicate", "Copyright", "Create", "CreateNewFolder", "CreditCard", "Crop", "Crop169", "Crop32", "Crop54", "Crop75", "CropDin", "CropFree", "CropLandscape", "CropOriginal", "CropPortrait", "CropRotate", "CropSquare", "Dashboard", "DataUsage", "DateRange", "Dehaze", "Delete", "DeleteForever", "DeleteSweep", "Description", "DesktopMac", "DesktopWindows", "Details", "DeveloperBoard", "DeveloperMode", "DeviceHub", "Devices", "DevicesOther", "DialerSip", "Dialpad", "Directions", "DirectionsBike", "DirectionsBoat", "DirectionsBus", "DirectionsCar", "DirectionsRailway", "DirectionsRun", "DirectionsSubway", "DirectionsTransit", "DirectionsWalk", "DiscFull", "Dns", "DoNotDisturb", "DoNotDisturbAlt", "DoNotDisturbOff", "DoNotDisturbOn", "Dock", "Domain", "Done", "DoneAll", "DonutLarge", "DonutSmall", "Drafts", "DragHandle", "DriveEta", "Dvr", "Edit", "EditLocation", "Eject", "Email", "EnhancedEncryption", "Equalizer", "Error", "ErrorOutline", "EuroSymbol", "EvStation", "Event", "EventAvailable", "EventBusy", "EventNote", "EventSeat", "ExitToApp", "ExpandLess", "ExpandMore", "Explicit", "Explore", "Exposure", "ExposureNeg1", "ExposureNeg2", "ExposurePlus1", "ExposurePlus2", "ExposureZero", "ExtensionIcon", "Face", "FastForward", "FastRewind", "Favorite", "FavoriteBorder", "FeaturedPlayList", "FeaturedVideo", "Feedback", "FiberDvr", "FiberManualRecord", "FiberNew", "FiberPin", "FiberSmartRecord", "FileDownload", "FileUpload", "Filter", "Filter1", "Filter2", "Filter3", "Filter4", "Filter5", "Filter6", "Filter7", "Filter8", "Filter9", "Filter9Plus", "FilterBAndW", "FilterCenterFocus", "FilterDrama", "FilterFrames", "FilterHdr", "FilterList", "FilterNone", "FilterTiltShift", "FilterVintage", "FindInPage", "FindReplace", "Fingerprint", "FirstPage", "FitnessCenter", "Flag", "Flare", "FlashAuto", "FlashOff", "FlashOn", "Flight", "FlightLand", "FlightTakeoff", "Flip", "FlipToBack", "FlipToFront", "Folder", "FolderOpen", "FolderShared", "FolderSpecial", "FontDownload", "FormatAlignCenter", "FormatAlignJustify", "FormatAlignLeft", "FormatAlignRight", "FormatBold", "FormatClear", "FormatColorFill", "FormatColorReset", "FormatColorText", "FormatIndentDecrease", "FormatIndentIncrease", "FormatItalic", "FormatLineSpacing", "FormatListBulleted", "FormatListNumbered", "FormatPaint", "FormatQuote", "FormatShapes", "FormatSize", "FormatStrikethrough", "FormatTextdirectionLToR", "FormatTextdirectionRToL", "FormatUnderlined", "Forum", "Forward", "Forward10", "Forward30", "Forward5", "FreeBreakfast", "Fullscreen", "FullscreenExit", "Functions", "GTranslate", "Gamepad", "Games", "Gavel", "Gesture", "GetApp", "Gif", "GolfCourse", "GpsFixed", "GpsNotFixed", "GpsOff", "Grade", "Gradient", "Grain", "GraphicEq", "GridOff", "GridOn", "Group", "GroupAdd", "GroupWork", "Hd", "HdrOff", "HdrOn", "HdrStrong", "HdrWeak", "Headset", "HeadsetMic", "Healing", "Hearing", "Help", "HelpOutline", "HighQuality", "Highlight", "HighlightOff", "History", "Home", "HotTub", "Hotel", "HourglassEmpty", "HourglassFull", "Http", "Https", "Image", "ImageAspectRatio", "ImportContacts", "ImportExport", "ImportantDevices", "Inbox", "IndeterminateCheckBox", "Info", "InfoOutline", "Input", "InsertChart", "InsertComment", "InsertDriveFile", "InsertEmoticon", "InsertInvitation", "InsertLink", "InsertPhoto", "InvertColors", "InvertColorsOff", "Iso", "Keyboard", "KeyboardArrowDown", "KeyboardArrowLeft", "KeyboardArrowRight", "KeyboardArrowUp", "KeyboardBackspace", "KeyboardCapslock", "KeyboardHide", "KeyboardReturn", "KeyboardTab", "KeyboardVoice", "Kitchen", "Label", "LabelOutline", "Landscape", "Language", "Laptop", "LaptopChromebook", "LaptopMac", "LaptopWindows", "LastPage", "Launch", "Layers", "LayersClear", "LeakAdd", "LeakRemove", "Lens", "LibraryAdd", "LibraryBooks", "LibraryMusic", "LightbulbOutline", "LineStyle", "LineWeight", "LinearScale", "Link", "LinkedCamera", "List", "LiveHelp", "LiveTv", "LocalActivity", "LocalAirport", "LocalAtm", "LocalBar", "LocalCafe", "LocalCarWash", "LocalConvenienceStore", "LocalDining", "LocalDrink", "LocalFlorist", "LocalGasStation", "LocalGroceryStore", "LocalHospital", "LocalHotel", "LocalLaundryService", "LocalLibrary", "LocalMall", "LocalMovies", "LocalOffer", "LocalParking", "LocalPharmacy", "LocalPhone", "LocalPizza", "LocalPlay", "LocalPostOffice", "LocalPrintshop", "LocalSee", "LocalShipping", "LocalTaxi", "LocationCity", "LocationDisabled", "LocationOff", "LocationOn", "LocationSearching", "Lock", "LockOpen", "LockOutline", "Looks", "Looks3", "Looks4", "Looks5", "Looks6", "LooksOne", "LooksTwo", "Loop", "Loupe", "LowPriority", "Loyalty", "Mail", "MailOutline", "Map", "Markunread", "MarkunreadMailbox", "Memory", "Menu", "MergeType", "Message", "Mic", "MicNone", "MicOff", "Mms", "ModeComment", "ModeEdit", "MonetizationOn", "MoneyOff", "MonochromePhotos", "Mood", "MoodBad", "More", "MoreHoriz", "MoreVert", "Motorcycle", "Mouse", "MoveToInbox", "Movie", "MovieCreation", "MovieFilter", "MultilineChart", "MusicNote", "MusicVideo", "MyLocation", "Nature", "NaturePeople", "NavigateBefore", "NavigateNext", "Navigation", "NearMe", "NetworkCell", "NetworkCheck", "NetworkLocked", "NetworkWifi", "NewReleases", "NextWeek", "Nfc", "NoEncryption", "NoSim", "NotInterested", "Note", "NoteAdd", "Notifications", "NotificationsActive", "NotificationsNone", "NotificationsOff", "NotificationsPaused", "OfflinePin", "OndemandVideo", "Opacity", "OpenInBrowser", "OpenInNew", "OpenWith", "Pages", "Pageview", "Palette", "PanTool", "Panorama", "PanoramaFishEye", "PanoramaHorizontal", "PanoramaVertical", "PanoramaWideAngle", "PartyMode", "Pause", "PauseCircleFilled", "PauseCircleOutline", "Payment", "People", "PeopleOutline", "PermCameraMic", "PermContactCalendar", "PermDataSetting", "PermDeviceInformation", "PermIdentity", "PermMedia", "PermPhoneMsg", "PermScanWifi", "Person", "PersonAdd", "PersonOutline", "PersonPin", "PersonPinCircle", "PersonalVideo", "Pets", "Phone", "PhoneAndroid", "PhoneBluetoothSpeaker", "PhoneForwarded", "PhoneInTalk", "PhoneIphone", "PhoneLocked", "PhoneMissed", "PhonePaused", "Phonelink", "PhonelinkErase", "PhonelinkLock", "PhonelinkOff", "PhonelinkRing", "PhonelinkSetup", "Photo", "PhotoAlbum", "PhotoCamera", "PhotoFilter", "PhotoLibrary", "PhotoSizeSelectActual", "PhotoSizeSelectLarge", "PhotoSizeSelectSmall", "PictureAsPdf", "PictureInPicture", "PictureInPictureAlt", "PieChart", "PieChartOutlined", "PinDrop", "Place", "PlayArrow", "PlayCircleFilled", "PlayCircleOutline", "PlayForWork", "PlaylistAdd", "PlaylistAddCheck", "PlaylistPlay", "PlusOne", "Poll", "Polymer", "Pool", "PortableWifiOff", "Portrait", "Power", "PowerInput", "PowerSettingsNew", "PregnantWoman", "PresentToAll", "Print", "PriorityHigh", "PublicIcon", "Publish", "QueryBuilder", "QuestionAnswer", "Queue", "QueueMusic", "QueuePlayNext", "Radio", "RadioButtonChecked", "RadioButtonUnchecked", "RateReview", "Receipt", "RecentActors", "RecordVoiceOver", "Redeem", "Redo", "Refresh", "Remove", "RemoveCircle", "RemoveCircleOutline", "RemoveFromQueue", "RemoveRedEye", "RemoveShoppingCart", "Reorder", "RepeatIcon", "RepeatOne", "Replay", "Replay10", "Replay30", "Replay5", "Reply", "ReplyAll", "Report", "ReportProblem", "Restaurant", "RestaurantMenu", "Restore", "RestorePage", "RingVolume", "Room", "RoomService", "Rotate90DegreesCcw", "RotateLeft", "RotateRight", "RoundedCorner", "Router", "Rowing", "RssFeed", "RvHookup", "Satellite", "Save", "Scanner", "Schedule", "School", "ScreenLockLandscape", "ScreenLockPortrait", "ScreenLockRotation", "ScreenRotation", "ScreenShare", "SdCard", "SdStorage", "Search", "Security", "SelectAll", "Send", "SentimentDissatisfied", "SentimentNeutral", "SentimentSatisfied", "SentimentVeryDissatisfied", "SentimentVerySatisfied", "Settings", "SettingsApplications", "SettingsBackupRestore", "SettingsBluetooth", "SettingsBrightness", "SettingsCell", "SettingsEthernet", "SettingsInputAntenna", "SettingsInputComponent", "SettingsInputComposite", "SettingsInputHdmi", "SettingsInputSvideo", "SettingsOverscan", "SettingsPhone", "SettingsPower", "SettingsRemote", "SettingsSystemDaydream", "SettingsVoice", "Share", "Shop", "ShopTwo", "ShoppingBasket", "ShoppingCart", "ShortText", "ShowChart", "Shuffle", "SignalCellular4Bar", "SignalCellularConnectedNoInternet4Bar", "SignalCellularNoSim", "SignalCellularNull", "SignalCellularOff", "SignalWifi4Bar", "SignalWifi4BarLock", "SignalWifiOff", "SimCard", "SimCardAlert", "SkipNext", "SkipPrevious", "Slideshow", "SlowMotionVideo", "Smartphone", "SmokeFree", "SmokingRooms", "Sms", "SmsFailed", "Snooze", "Sort", "SortByAlpha", "Spa", "SpaceBar", "Speaker", "SpeakerGroup", "SpeakerNotes", "SpeakerNotesOff", "SpeakerPhone", "Spellcheck", "Star", "StarBorder", "StarHalf", "Stars", "StayCurrentLandscape", "StayCurrentPortrait", "StayPrimaryLandscape", "StayPrimaryPortrait", "Stop", "StopScreenShare", "Storage", "Store", "StoreMallDirectory", "Straighten", "Streetview", "StrikethroughS", "Style", "SubdirectoryArrowLeft", "SubdirectoryArrowRight", "Subject", "Subscriptions", "Subtitles", "Subway", "SupervisorAccount", "SurroundSound", "SwapCalls", "SwapHoriz", "SwapVert", "SwapVerticalCircle", "SwitchCamera", "SwitchVideo", "Sync", "SyncDisabled", "SyncProblem", "SystemUpdate", "SystemUpdateAlt", "Tab", "TabUnselected", "Tablet", "TabletAndroid", "TabletMac", "TagFaces", "TapAndPlay", "Terrain", "TextFields", "TextFormat", "Textsms", "Texture", "Theaters", "ThreedRotation", "ThumbDown", "ThumbUp", "ThumbsUpDown", "TimeToLeave", "Timelapse", "Timeline", "Timer", "Timer10", "Timer3", "TimerOff", "Title", "Toc", "Today", "Toll", "Tonality", "TouchApp", "Toys", "TrackChanges", "Traffic", "Train", "Tram", "TransferWithinAStation", "Transform", "Translate", "TrendingDown", "TrendingFlat", "TrendingUp", "Tune", "TurnedIn", "TurnedInNot", "Tv", "Unarchive", "Undo", "UnfoldLess", "UnfoldMore", "Update", "Usb", "VerifiedUser", "VerticalAlignBottom", "VerticalAlignCenter", "VerticalAlignTop", "Vibration", "VideoCall", "VideoLabel", "VideoLibrary", "Videocam", "VideocamOff", "VideogameAsset", "ViewAgenda", "ViewArray", "ViewCarousel", "ViewColumn", "ViewComfy", "ViewCompact", "ViewDay", "ViewHeadline", "ViewList", "ViewModule", "ViewQuilt", "ViewStream", "ViewWeek", "Vignette", "Visibility", "VisibilityOff", "VoiceChat", "Voicemail", "VolumeDown", "VolumeMute", "VolumeOff", "VolumeUp", "VpnKey", "VpnLock", "Wallpaper", "Warning", "Watch", "WatchLater", "WbAuto", "WbCloudy", "WbIncandescent", "WbIridescent", "WbSunny", "Wc", "Web", "WebAsset", "Weekend", "Whatshot", "Widgets", "Wifi", "WifiLock", "WifiTethering", "Work", "WrapText", "YoutubeSearchedFor", "ZoomIn", "ZoomOut", "ZoomOutMap"]
    
    let openiconicIcons = ["AccountLogin", "AccountLogout", "ActionRedo", "ActionUndo", "AlignCenter", "AlignLeft", "AlignRight", "Aperture", "ArrowBottom", "ArrowCircleBottom", "ArrowCircleLeft", "ArrowCircleRight", "ArrowCircleTop", "ArrowLeft", "ArrowRight", "ArrowThickBottom", "ArrowThickLeft", "ArrowThickRight", "ArrowThickTop", "ArrowTop", "Audio", "AudioSpectrum", "Badge", "Ban", "BarChart", "Basket", "BatteryEmpty", "BatteryFull", "Beaker", "Bell", "Bluetooth", "Bold", "Bolt", "Book", "Bookmark", "Box", "Briefcase", "BritishPound", "Browser", "Brush", "Bug", "Bullhorn", "Calculator", "Calendar", "CameraSlr", "CaretBottom", "CaretLeft", "CaretRight", "CaretTop", "Cart", "Chat", "Check", "ChevronBottom", "ChevronLeft", "ChevronRight", "ChevronTop", "CircleCheck", "CircleX", "Clipboard", "Clock", "Cloud", "CloudDownload", "CloudUpload", "Cloudy", "Code", "Cog", "CollapseDown", "CollapseLeft", "CollapseRight", "CollapseUp", "Command", "CommentSquare", "Compass", "Contrast", "Copywriting", "CreditCard", "Crop", "Dashboard", "DataTransferDownload", "DataTransferUpload", "Delete", "Dial", "Document", "Dollar", "DoubleQuoteSansLeft", "DoubleQuoteSansRight", "DoubleQuoteSerifLeft", "DoubleQuoteSerifRight", "Droplet", "Eject", "Elevator", "Ellipses", "EnvelopeClosed", "EnvelopeOpen", "Euro", "Excerpt", "ExpandDown", "ExpandLeft", "ExpandRight", "ExpandUp", "ExternalLink", "Eye", "Eyedropper", "File", "Fire", "Flag", "Flash", "Folder", "Fork", "FullscreenEnter", "FullscreenExit", "Globe", "Graph", "GridFourUp", "GridThreeUp", "GridTwoUp", "HardDrive", "Header", "Headphones", "Heart", "Home", "Image", "Inbox", "Infinity", "Info", "Italic", "JustifyCenter", "JustifyLeft", "JustifyRight", "Key", "Laptop", "Layers", "Lightbulb", "LinkBroken", "LinkIntact", "List", "ListRich", "Location", "LockLocked", "LockUnlocked", "Loop", "LoopCircular", "LoopSquare", "MagnifyingGlass", "Map", "MapMarker", "MediaPause", "MediaPlay", "MediaRecord", "MediaSkipBackward", "MediaSkipForward", "MediaStepBackward", "MediaStepForward", "MediaStop", "MedicalCross", "Menu", "Microphone", "Minus", "Monitor", "Moon", "Move", "MusicalNote", "Paperclip", "Pencil", "People", "Person", "Phone", "PieChart", "Pin", "PlayCircle", "Plus", "PowerStandby", "Print", "Project", "Pulse", "PuzzlePiece", "QuestionMark", "Rain", "Random", "Reload", "ResizeBoth", "ResizeHeight", "ResizeWidth", "Rss", "RssAlt", "Script", "Share", "ShareBoxed", "Shield", "Signal", "Signpost", "SortAscending", "SortDescending", "Spreadsheet", "Star", "Sun", "Tablet", "Tag", "Tags", "Target", "Task", "Terminal", "Text", "ThumbDown", "ThumbUp", "Timer", "Transfer", "Trash", "Underline", "VerticalAlignBottom", "VerticalAlignCenter", "VerticalAlignTop", "Video", "VolumeHigh", "VolumeLow", "VolumeOff", "Warning", "Wifi", "Wrench", "X", "Yen", "ZoomIn", "ZoomOut"]
    
    let stateIcons = ["AK", "AL", "AR", "AZ", "CA", "CO", "CT", "DC", "DE", "FL", "GA", "HI", "IA", "ID", "IL", "IN", "KS", "KY", "LA", "MA", "MD", "ME", "MI", "MN", "MO", "MS", "MT", "NC", "ND", "NE", "NH", "NJ", "NM", "NV", "NY", "OH", "OK", "OR", "PA", "RI", "SC", "SD", "TN", "TX", "US", "UT", "VA", "VT", "WA", "WI", "WV", "WY"]
    
    let weatherIcons = ["Alien", "Barometer", "Celsius", "Cloud", "CloudDown", "CloudRefresh", "CloudUp", "Cloudy", "CloudyGusts", "CloudyWindy", "DayCloudy", "DayCloudyGusts", "DayCloudyHigh", "DayCloudyWindy", "DayFog", "DayHail", "DayHaze", "DayLightWind", "DayLightning", "DayRain", "DayRainMix", "DayRainWind", "DayShowers", "DaySleet", "DaySleetStorm", "DaySnow", "DaySnowThunderstorm", "DaySnowWind", "DaySprinkle", "DayStormShowers", "DaySunny", "DaySunnyOvercast", "DayThunderstorm", "DayWindy", "Degrees", "DirectionDown", "DirectionDownLeft", "DirectionDownRight", "DirectionLeft", "DirectionRight", "DirectionUp", "DirectionUpLeft", "DirectionUpRight", "Dust", "Earthquake", "Fahrenheit", "Fire", "Flood", "Fog", "ForecastIoClearDay", "ForecastIoClearNight", "ForecastIoCloudy", "ForecastIoFog", "ForecastIoHail", "ForecastIoPartlyCloudyDay", "ForecastIoPartlyCloudyNight", "ForecastIoRain", "ForecastIoSleet", "ForecastIoSnow", "ForecastIoThunderstorm", "ForecastIoTornado", "ForecastIoWind", "GaleWarning", "Hail", "Horizon", "HorizonAlt", "Hot", "Humidity", "Hurricane", "HurricaneWarning", "Lightning", "LunarEclipse", "Meteor", "Moon0", "Moon1", "Moon10", "Moon11", "Moon12", "Moon13", "Moon14", "Moon15", "Moon16", "Moon17", "Moon18", "Moon19", "Moon2", "Moon20", "Moon21", "Moon22", "Moon23", "Moon24", "Moon25", "Moon26", "Moon27", "Moon3", "Moon4", "Moon5", "Moon6", "Moon7", "Moon8", "Moon9", "MoonAltFirstQuarter", "MoonAltFull", "MoonAltNew", "MoonAltThirdQuarter", "MoonAltWaningCrescent1", "MoonAltWaningCrescent2", "MoonAltWaningCrescent3", "MoonAltWaningCrescent4", "MoonAltWaningCrescent5", "MoonAltWaningCrescent6", "MoonAltWaningGibbous1", "MoonAltWaningGibbous2", "MoonAltWaningGibbous3", "MoonAltWaningGibbous4", "MoonAltWaningGibbous5", "MoonAltWaningGibbous6", "MoonAltWaxingCrescent1", "MoonAltWaxingCrescent2", "MoonAltWaxingCrescent3", "MoonAltWaxingCrescent4", "MoonAltWaxingCrescent5", "MoonAltWaxingCrescent6", "MoonAltWaxingGibbous1", "MoonAltWaxingGibbous2", "MoonAltWaxingGibbous3", "MoonAltWaxingGibbous4", "MoonAltWaxingGibbous5", "MoonAltWaxingGibbous6", "MoonFirstQuarter", "MoonFull", "MoonNew", "MoonThirdQuarter", "MoonWaningCrescent1", "MoonWaningCrescent2", "MoonWaningCrescent3", "MoonWaningCrescent4", "MoonWaningCrescent5", "MoonWaningCrescent6", "MoonWaningGibbous1", "MoonWaningGibbous2", "MoonWaningGibbous3", "MoonWaningGibbous4", "MoonWaningGibbous5", "MoonWaningGibbous6", "MoonWaxingCrescent1", "MoonWaxingCrescent2", "MoonWaxingCrescent3", "MoonWaxingCrescent4", "MoonWaxingCrescent5", "MoonWaxingCrescent6", "MoonWaxingGibbous1", "MoonWaxingGibbous2", "MoonWaxingGibbous3", "MoonWaxingGibbous4", "MoonWaxingGibbous5", "MoonWaxingGibbous6", "Moonrise", "Moonset", "Na", "NightAltCloudy", "NightAltCloudyGusts", "NightAltCloudyHigh", "NightAltCloudyWindy", "NightAltHail", "NightAltLightning", "NightAltPartlyCloudy", "NightAltRain", "NightAltRainMix", "NightAltRainWind", "NightAltShowers", "NightAltSleet", "NightAltSleetStorm", "NightAltSnow", "NightAltSnowThunderstorm", "NightAltSnowWind", "NightAltSprinkle", "NightAltStormShowers", "NightAltThunderstorm", "NightClear", "NightCloudy", "NightCloudyGusts", "NightCloudyHigh", "NightCloudyWindy", "NightFog", "NightHail", "NightLightning", "NightPartlyCloudy", "NightRain", "NightRainMix", "NightRainWind", "NightShowers", "NightSleet", "NightSleetStorm", "NightSnow", "NightSnowThunderstorm", "NightSnowWind", "NightSprinkle", "NightStormShowers", "NightThunderstorm", "Owm200", "Owm201", "Owm202", "Owm210", "Owm211", "Owm212", "Owm221", "Owm230", "Owm231", "Owm232", "Owm300", "Owm301", "Owm302", "Owm310", "Owm311", "Owm312", "Owm313", "Owm314", "Owm321", "Owm500", "Owm501", "Owm502", "Owm503", "Owm504", "Owm511", "Owm520", "Owm521", "Owm522", "Owm531", "Owm600", "Owm601", "Owm602", "Owm611", "Owm612", "Owm615", "Owm616", "Owm620", "Owm621", "Owm622", "Owm701", "Owm711", "Owm721", "Owm731", "Owm741", "Owm761", "Owm762", "Owm771", "Owm781", "Owm800", "Owm801", "Owm802", "Owm803", "Owm804", "Owm900", "Owm901", "Owm902", "Owm903", "Owm904", "Owm905", "Owm906", "Owm957", "OwmDay200", "OwmDay201", "OwmDay202", "OwmDay210", "OwmDay211", "OwmDay212", "OwmDay221", "OwmDay230", "OwmDay231", "OwmDay232", "OwmDay300", "OwmDay301", "OwmDay302", "OwmDay310", "OwmDay311", "OwmDay312", "OwmDay313", "OwmDay314", "OwmDay321", "OwmDay500", "OwmDay501", "OwmDay502", "OwmDay503", "OwmDay504", "OwmDay511", "OwmDay520", "OwmDay521", "OwmDay522", "OwmDay531", "OwmDay600", "OwmDay601", "OwmDay602", "OwmDay611", "OwmDay612", "OwmDay615", "OwmDay616", "OwmDay620", "OwmDay621", "OwmDay622", "OwmDay701", "OwmDay711", "OwmDay721", "OwmDay731", "OwmDay741", "OwmDay761", "OwmDay762", "OwmDay781", "OwmDay800", "OwmDay801", "OwmDay802", "OwmDay803", "OwmDay804", "OwmDay900", "OwmDay902", "OwmDay903", "OwmDay904", "OwmDay906", "OwmDay957", "OwmNight200", "OwmNight201", "OwmNight202", "OwmNight210", "OwmNight211", "OwmNight212", "OwmNight221", "OwmNight230", "OwmNight231", "OwmNight232", "OwmNight300", "OwmNight301", "OwmNight302", "OwmNight310", "OwmNight311", "OwmNight312", "OwmNight313", "OwmNight314", "OwmNight321", "OwmNight500", "OwmNight501", "OwmNight502", "OwmNight503", "OwmNight504", "OwmNight511", "OwmNight520", "OwmNight521", "OwmNight522", "OwmNight531", "OwmNight600", "OwmNight601", "OwmNight602", "OwmNight611", "OwmNight612", "OwmNight615", "OwmNight616", "OwmNight620", "OwmNight621", "OwmNight622", "OwmNight701", "OwmNight711", "OwmNight721", "OwmNight731", "OwmNight741", "OwmNight761", "OwmNight762", "OwmNight781", "OwmNight800", "OwmNight801", "OwmNight802", "OwmNight803", "OwmNight804", "OwmNight900", "OwmNight902", "OwmNight903", "OwmNight904", "OwmNight906", "OwmNight957", "Rain", "RainMix", "RainWind", "Raindrop", "Raindrops", "Refresh", "RefreshAlt", "Sandstorm", "Showers", "Sleet", "SmallCraftAdvisory", "Smog", "Smoke", "Snow", "SnowWind", "SnowflakeCold", "SolarEclipse", "Sprinkle", "Stars", "StormShowers", "StormWarning", "StrongWind", "Sunrise", "Sunset", "Thermometer", "ThermometerExterior", "ThermometerInternal", "Thunderstorm", "Time1", "Time10", "Time11", "Time12", "Time2", "Time3", "Time4", "Time5", "Time6", "Time7", "Time8", "Time9", "Tornado", "Train", "Tsunami", "Umbrella", "Volcano", "WindBeaufort0", "WindBeaufort1", "WindBeaufort10", "WindBeaufort11", "WindBeaufort12", "WindBeaufort2", "WindBeaufort3", "WindBeaufort4", "WindBeaufort5", "WindBeaufort6", "WindBeaufort7", "WindBeaufort8", "WindBeaufort9", "WindDirection", "Windy", "Wmo46800", "Wmo468000", "Wmo468001", "Wmo468002", "Wmo468003", "Wmo468004", "Wmo468005", "Wmo46801", "Wmo468010", "Wmo468011", "Wmo468012", "Wmo468018", "Wmo46802", "Wmo468020", "Wmo468021", "Wmo468022", "Wmo468023", "Wmo468024", "Wmo468025", "Wmo468026", "Wmo468027", "Wmo468028", "Wmo468029", "Wmo46803", "Wmo468030", "Wmo468031", "Wmo468032", "Wmo468033", "Wmo468034", "Wmo468035", "Wmo46804", "Wmo468040", "Wmo468041", "Wmo468042", "Wmo468043", "Wmo468044", "Wmo468045", "Wmo468046", "Wmo468047", "Wmo468048", "Wmo46805", "Wmo468050", "Wmo468051", "Wmo468052", "Wmo468053", "Wmo468054", "Wmo468055", "Wmo468056", "Wmo468057", "Wmo468058", "Wmo468060", "Wmo468061", "Wmo468062", "Wmo468063", "Wmo468064", "Wmo468065", "Wmo468066", "Wmo468067", "Wmo468068", "Wmo468070", "Wmo468071", "Wmo468072", "Wmo468073", "Wmo468074", "Wmo468075", "Wmo468076", "Wmo468077", "Wmo468078", "Wmo468080", "Wmo468081", "Wmo468082", "Wmo468083", "Wmo468084", "Wmo468085", "Wmo468086", "Wmo468087", "Wmo468089", "Wmo468090", "Wmo468091", "Wmo468092", "Wmo468093", "Wmo468094", "Wmo468095", "Wmo468096", "Wmo468099", "WuChanceflurries", "WuChancerain", "WuChancesleat", "WuChancesnow", "WuChancetstorms", "WuClear", "WuCloudy", "WuFlurries", "WuHazy", "WuMostlycloudy", "WuMostlysunny", "WuPartlycloudy", "WuPartlysunny", "WuRain", "WuSleat", "WuSnow", "WuSunny", "WuTstorms", "WuUnknown", "Yahoo0", "Yahoo1", "Yahoo10", "Yahoo11", "Yahoo12", "Yahoo13", "Yahoo14", "Yahoo15", "Yahoo16", "Yahoo17", "Yahoo18", "Yahoo19", "Yahoo2", "Yahoo20", "Yahoo21", "Yahoo22", "Yahoo23", "Yahoo24", "Yahoo25", "Yahoo26", "Yahoo27", "Yahoo28", "Yahoo29", "Yahoo3", "Yahoo30", "Yahoo31", "Yahoo32", "Yahoo3200", "Yahoo33", "Yahoo34", "Yahoo35", "Yahoo36", "Yahoo37", "Yahoo38", "Yahoo39", "Yahoo4", "Yahoo40", "Yahoo41", "Yahoo42", "Yahoo43", "Yahoo44", "Yahoo45", "Yahoo46", "Yahoo47", "Yahoo5", "Yahoo6", "Yahoo7", "Yahoo8", "Yahoo9"]
    
    let icofontIcons = ["fiveStarHotel", "abacus", "abacusAlt", "abc", "addons", "addressBook", "adjust", "aids", "airBalloon", "airplane", "airplaneAlt", "alarm", "alignCenter", "alignLeft", "alignRight", "allCaps", "amazon", "amazonAlt", "ambulance", "ambulanceCrescent", "ambulanceCross", "americanExpress", "americanExpressAlt", "anchor", "anchorAlt", "androidNexus", "androidTablet", "angle", "angryMonster", "animalBat", "animalBear", "animalBearTracks", "animalBird", "animalBirdAlt", "animalBone", "animalBull", "animalCamel", "animalCamelAlt", "animalCamelHead", "animalCat", "animalCatAlt1", "animalCatAlt2", "animalCatAlt3", "animalCatAlt4", "animalCatWithDog", "animalCow", "animalCowHead", "animalCrab", "animalCrocodile", "animalDeerHead", "animalDog", "animalDogAlt", "animalDogBarking", "animalDolphin", "animalDuckTracks", "animalEagleHead", "animalEatenFish", "animalElephant", "animalElephantAlt", "animalElephantHead", "animalElephantHeadAlt", "animalElk", "animalFish", "animalFishAlt1", "animalFishAlt2", "animalFishAlt3", "animalFishAlt4", "animalFox", "animalFoxAlt", "animalFrog", "animalFrogTracks", "animalFroggy", "animalGiraffe", "animalGiraffeAlt", "animalGoatHead", "animalGoatHeadAlt1", "animalGoatHeadAlt2", "animalGorilla", "animalHenTracks", "animalHorseHead", "animalHorseHeadAlt1", "animalHorseHeadAlt2", "animalHorseTracks", "animalJellyfish", "animalKangaroo", "animalLemur", "animalLion", "animalLionAlt", "animalLionHead", "animalLionHeadAlt", "animalMonkey", "animalMonkeyAlt1", "animalMonkeyAlt2", "animalMonkeyAlt3", "animalOctopus", "animalOctopusAlt", "animalOwl", "animalPanda", "animalPandaAlt", "animalPanther", "animalParrot", "animalParrotLip", "animalPaw", "animalPelican", "animalPenguin", "animalPig", "animalPigAlt", "animalPigeon", "animalPigeonAlt", "animalPigeons", "animalRabbitRunning", "animalRatAlt", "animalRhino", "animalRhinoHead", "animalRooster", "animalSeahorse", "animalSeal", "animalShrimp", "animalSnail", "animalSnailAlt1", "animalSnailAlt2", "animalSnake", "animalSquid", "animalSquirrel", "animalTiger", "animalTigerAlt", "animalTurtle", "animalWhale", "animalWoodpecker", "animalZebra", "apple", "applePay", "applePayAlt", "appleWatch", "arabianCoffee", "architecture", "architectureAlt", "archive", "arrowDown", "arrowLeft", "arrowRight", "arrowUp", "artichoke", "articulatedTruck", "asparagus", "at", "atom", "attachment", "audio", "autism", "autoMobile", "autoRickshaw", "automation", "avocado", "award", "baby", "babyCloth", "babyFood", "babyMilkBottle", "babyTrolley", "backPack", "badge", "badmintonBirdie", "bag", "bagAlt", "ban", "banana", "bandage", "bank", "bankAlt", "bankTransfer", "bankTransferAlt", "barCode", "barcode", "barricade", "bars", "baseball", "baseballer", "basket", "basketball", "basketballHoop", "bathtub", "batteryEmpty", "batteryFull", "batteryHalf", "batteryLow", "bbq", "beach", "beachBed", "beaker", "beans", "bear", "beard", "bed", "bedPatient", "beer", "bell", "bellAlt", "bellPepperCapsicum", "beverage", "bicycle", "bicycleAlt1", "bicycleAlt2", "bill", "billAlt", "billboard", "billiardBall", "bin", "binary", "binoculars", "bird", "birdWings", "birds", "birthdayCake", "blackBoard", "blind", "blockDown", "blockLeft", "blockRight", "blockUp", "blood", "bloodDrop", "bloodTest", "bluetooth", "bold", "bolt", "bomb", "book", "bookAlt", "bookMark", "boot", "bootAlt1", "bootAlt2", "bow", "bowling", "bowlingAlt", "box", "boy", "brain", "brainAlt", "brainstorming", "braintree", "braintreeAlt", "brandAcer", "brandAdidas", "brandAdobe", "brandAirNewZealand", "brandAirbnb", "brandAircell", "brandAirtel", "brandAlcatel", "brandAlibaba", "brandAliexpress", "brandAlipay", "brandAmazon", "brandAmd", "brandAmericanAirlines", "brandAndroid", "brandAndroidRobot", "brandAol", "brandApple", "brandAppstore", "brandAsus", "brandAti", "brandAtt", "brandAudi", "brandAxiata", "brandBada", "brandBbc", "brandBing", "brandBlackberry", "brandBmw", "brandBox", "brandBurgerKing", "brandBusinessInsider", "brandBuzzfeed", "brandCannon", "brandCasio", "brandChinaMobile", "brandChinaTelecom", "brandChinaUnicom", "brandCisco", "brandCitibank", "brandCnet", "brandCnn", "brandCocalCola", "brandCompaq", "brandCopy", "brandDebian", "brandDelicious", "brandDell", "brandDesignbump", "brandDesignfloat", "brandDisney", "brandDodge", "brandDove", "brandDrupal", "brandEbay", "brandEleven", "brandEmirates", "brandEspn", "brandEtihadAirways", "brandEtisalat", "brandEtsy", "brandFacebook", "brandFastrack", "brandFedex", "brandFerrari", "brandFitbit", "brandFlikr", "brandForbes", "brandFoursquare", "brandFox", "brandFoxconn", "brandFujitsu", "brandGeneralElectric", "brandGillette", "brandGizmodo", "brandGnome", "brandGoogle", "brandGopro", "brandGucci", "brandHallmark", "brandHi5", "brandHonda", "brandHp", "brandHsbc", "brandHtc", "brandHuawei", "brandHulu", "brandHyundai", "brandIbm", "brandIcofont", "brandIcq", "brandIkea", "brandImdb", "brandIndiegogo", "brandIntel", "brandIpair", "brandJaguar", "brandJava", "brandJoomla", "brandJoomshaper", "brandKickstarter", "brandKik", "brandLastfm", "brandLego", "brandLenovo", "brandLevis", "brandLexus", "brandLg", "brandLifeHacker", "brandLineMessenger", "brandLinkedin", "brandLinux", "brandLinuxMint", "brandLionix", "brandLiveMessenger", "brandLoreal", "brandLouisVuitton", "brandMacOs", "brandMarvelApp", "brandMashable", "brandMazda", "brandMcdonals", "brandMercedes", "brandMicromax", "brandMicrosoft", "brandMobileme", "brandMobily", "brandMotorola", "brandMsi", "brandMts", "brandMyspace", "brandMytv", "brandNasa", "brandNatgeo", "brandNbc", "brandNescafe", "brandNestle", "brandNetflix", "brandNexus", "brandNike", "brandNokia", "brandNvidia", "brandOmega", "brandOpensuse", "brandOracle", "brandPanasonic", "brandPaypal", "brandPepsi", "brandPhilips", "brandPizzaHut", "brandPlaystation", "brandPuma", "brandQatarAir", "brandQvc", "brandReadernaut", "brandRedbull", "brandReebok", "brandReuters", "brandSamsung", "brandSap", "brandSaudiaAirlines", "brandScribd", "brandShell", "brandSiemens", "brandSkTelecom", "brandSlideshare", "brandSmashingMagazine", "brandSnapchat", "brandSony", "brandSonyEricsson", "brandSoundcloud", "brandSprint", "brandSquidoo", "brandStarbucks", "brandStc", "brandSteam", "brandSuzuki", "brandSymbian", "brandTMobile", "brandTango", "brandTarget", "brandTataIndicom", "brandTechcrunch", "brandTelenor", "brandTeliasonera", "brandTesla", "brandTheVerge", "brandThenextweb", "brandToshiba", "brandToyota", "brandTribenet", "brandUbuntu", "brandUnilever", "brandVaio", "brandVerizon", "brandViber", "brandVodafone", "brandVolkswagen", "brandWalmart", "brandWarnerbros", "brandWhatsapp", "brandWikipedia", "brandWindows", "brandWire", "brandWordpress", "brandXiaomi", "brandYahoobuzz", "brandYamaha", "brandYoutube", "brandZain", "bread", "breakdown", "bricks", "briefcase", "briefcaseAlt1", "briefcaseAlt2", "broccoli", "broken", "brush", "bubbleDown", "bubbleLeft", "bubbleRight", "bubbleUp", "bucket", "bucket1", "bucket2", "bug", "building", "buildingAlt", "bullDozer", "bullet", "bullhorn", "bullseye", "burger", "burglar", "bus", "busAlt1", "busAlt2", "busAlt3", "businessMan", "businessManAlt1", "businessManAlt2", "businessManAlt3", "businessman", "businesswoman", "butterfly", "butterflyAlt", "cab", "cabbage", "cableCar", "calculations", "calculator", "calculatorAlt1", "calculatorAlt2", "calendar", "camera", "cameraAlt", "campingVest", "candy", "cannonFiring", "canoe", "capsule", "car", "carAlt1", "carAlt2", "carAlt3", "carAlt4", "card", "caretDown", "caretLeft", "caretRight", "caretUp", "carrot", "cart", "cartAlt", "cashOnDelivery", "cashOnDeliveryAlt", "cassette", "cassettePlayer", "castle", "cauliFlower", "cc", "ccCamera", "celsius", "cementMix", "cementMixer", "certificate", "certificateAlt1", "certificateAlt2", "chair", "charging", "chartArrowsAxis", "chartBarGraph", "chartFlow", "chartFlowAlt1", "chartFlowAlt2", "chartHistogram", "chartHistogramAlt", "chartLine", "chartLineAlt", "chartPie", "chartPieAlt", "chartRadarGraph", "chat", "check", "checkAlt", "checkCircled", "checked", "checkout", "checkoutAlt", "cheerLeader", "cheese", "chef", "cherry", "chicken", "chickenFry", "childrenCare", "circleRuler", "circleRulerAlt", "circledDown", "circledLeft", "circledRight", "circledUp", "circuit", "climbing", "clip", "clipBoard", "clockTime", "close", "closeCircled", "closeLine", "closeLineCircled", "closeLineSquared", "closeLineSquaredAlt", "closeSquared", "closeSquaredAlt", "cloud", "cloudDownload", "cloudRefresh", "cloudUpload", "clouds", "cloudy", "cocktail", "coconut", "coconutAlt", "code", "codeAlt", "codeNotAllowed", "coffeeAlt", "coffeeCup", "coffeeMug", "coffeePot", "coins", "cola", "collapse", "colorBucket", "colorPicker", "comment", "company", "compass", "compassAlt", "compassAlt1", "compassAlt2", "compassAlt3", "compassAlt4", "computer", "concreteMixer", "connection", "console", "contactAdd", "contacts", "contrast", "cop", "copBadge", "copy", "copyAlt", "copyBlack", "copyright", "corn", "corner", "court", "courtHammer", "creditCard", "croissant", "crop", "cropPlant", "crown", "crutches", "cube", "cubes", "cucumber", "culinary", "cupCake", "curAfghani", "curAfghaniFalse", "curAfghaniMinus", "curAfghaniPlus", "curAfghaniTrue", "curBaht", "curBahtFalse", "curBahtMinus", "curBahtPlus", "curBahtTrue", "curBitcoin", "curBitcoinFalse", "curBitcoinMinus", "curBitcoinPlus", "curBitcoinTrue", "curDollar", "curDollarFlase", "curDollarMinus", "curDollarPlus", "curDollarTrue", "curDong", "curDongFalse", "curDongMinus", "curDongPlus", "curDongTrue", "curEuro", "curEuroFalse", "curEuroMinus", "curEuroPlus", "curEuroTrue", "curFrank", "curFrankFalse", "curFrankMinus", "curFrankPlus", "curFrankTrue", "curHryvnia", "curHryvniaFalse", "curHryvniaMinus", "curHryvniaPlus", "curHryvniaTrue", "curLira", "curLiraFalse", "curLiraMinus", "curLiraPlus", "curLiraTrue", "curPeseta", "curPesetaFalse", "curPesetaMinus", "curPesetaPlus", "curPesetaTrue", "curPeso", "curPesoFalse", "curPesoMinus", "curPesoPlus", "curPesoTrue", "curPound", "curPoundFalse", "curPoundMinus", "curPoundPlus", "curPoundTrue", "curRenminbi", "curRenminbiFalse", "curRenminbiMinus", "curRenminbiPlus", "curRenminbiTrue", "curRiyal", "curRiyalFalse", "curRiyalMinus", "curRiyalPlus", "curRiyalTrue", "curRouble", "curRoubleFalse", "curRoubleMinus", "curRoublePlus", "curRoubleTrue", "curRupee", "curRupeeFalse", "curRupeeMinus", "curRupeePlus", "curRupeeTrue", "curTaka", "curTakaFalse", "curTakaMinus", "curTakaPlus", "curTakaTrue", "curTurkishLira", "curTurkishLiraFalse", "curTurkishLiraMinus", "curTurkishLiraPlus", "curTurkishLiraTrue", "curWon", "curWonFalse", "curWonMinus", "curWonPlus", "curWonTrue", "curYen", "curYenFalse", "curYenMinus", "curYenPlus", "curYenTrue", "cursorDrag", "curvedDoubleLeft", "curvedDoubleRight", "curvedDown", "curvedLeft", "curvedRight", "curvedUp", "cut", "cycling", "cyclist", "dangerZone", "dart", "dashboard", "dashboardWeb", "data", "database", "databaseAdd", "databaseLocked", "databaseRemove", "deal", "degrees", "degreesAlt1", "degreesAlt2", "delete", "deleteAlt", "deliveryTime", "diamond", "dice", "diceAlt", "dinersClub", "dinersClubAlt1", "dinersClubAlt2", "dinersClubAlt3", "diningTable", "directionSign", "disabilityRace", "disabled", "disc", "discover", "discoverAlt", "diskette", "divingGoggle", "dna", "dnaAlt1", "dnaAlt2", "doctor", "doctorAlt", "documentFolder", "documentSearch", "donut", "dottedDown", "dottedLeft", "dottedRight", "dottedUp", "doubleLeft", "doubleRight", "download", "downloadAlt", "downloaded", "drag", "drag1", "drag2", "drag3", "drill", "drug", "drugPack", "drwaingTablet", "dumbbell", "dumbbellAlt", "dust", "earphone", "earth", "ebook", "eclipse", "ecoEnergy", "ecoEnvironmen", "edit", "editAlt", "education", "eggPlant", "eggPoached", "eject", "electron", "email", "emoAngry", "emoAstonished", "emoConfounded", "emoConfused", "emoCrying", "emoDizzy", "emoExpressionless", "emoHeartEyes", "emoLaughing", "emoNerdSmile", "emoOpenMouth", "emoRage", "emoRollingEyes", "emoSad", "emoSimpleSmile", "emoSlightlySmile", "emoSmirk", "emoStuckOutTongue", "emoWinkSmile", "emoWorried", "energyAir", "energyOil", "energySavings", "energySolar", "energyWater", "engineer", "envelope", "envelopeOpen", "eraser", "eraserAlt", "error", "eway", "ewayAlt", "excavator", "exchange", "exclamation", "exclamationCircle", "exclamationSquare", "exclamationTringle", "exit", "expand", "expandAlt", "external", "externalLink", "eye", "eyeAlt", "eyeBlocked", "eyeDropper", "fahrenheit", "farmer", "farmer1", "fastDelivery", "fastFood", "favourite", "fax", "female", "field", "fieldAlt", "file", "fileAlt", "fileAudio", "fileAviMp4", "fileBmp", "fileCode", "fileCss", "fileDocument", "fileEps", "fileExcel", "fileExe", "fileFile", "fileFlv", "fileGif", "fileHtml5", "fileImage", "fileIso", "fileJava", "fileJavascript", "fileJpg", "fileMidi", "fileMov", "fileMp3", "filePdf", "filePhp", "filePng", "filePowerpoint", "filePresentation", "filePsb", "filePsd", "filePython", "fileRuby", "fileSpreadsheet", "fileSql", "fileSvg", "fileText", "fileTiff", "fileVideo", "fileWave", "fileWmv", "fileWord", "fileZip", "files", "film", "filter", "fingerPrint", "fire", "fireAlt", "fireBurn", "fireExtinguisher", "fireExtinguisherAlt", "fireTruck", "fireTruckAlt", "firstAid", "firstAidAlt", "fish", "fixTools", "flag", "flagAlt1", "flagAlt2", "flameTorch", "flash", "flashDrive", "flashLight", "flask", "flora", "floraFlower", "focus", "folder", "folderOpen", "folderSearch", "font", "foodBasket", "foodCart", "footPrint", "football", "footballAlt", "footballAmerican", "forestFire", "forkAndKnife", "forkLift", "forward", "foul", "fountainPen", "freeDelivery", "frenchFries", "freshJuice", "fruits", "fullNight", "fullSunny", "funkyMan", "game", "gameConsole", "gameControl", "gamePad", "garbage", "gavel", "gear", "gears", "gift", "giftBox", "girl", "girlAlt", "glass", "globe", "globeAlt", "glueOil", "goal", "goalKeeper", "goldenRatio", "golf", "golfAlt", "golfBag", "golfCart", "golfField", "golfer", "googleWallet", "googleWalletAlt1", "googleWalletAlt2", "googleWalletAlt3", "graduate", "graduateAlt", "graffiti", "grapes", "grocery", "group", "groupStudents", "growth", "guiter", "gym", "gymAlt1", "gymAlt2", "gymAlt3", "hail", "hailNight", "hailRainy", "hailRainyNight", "hailRainySunny", "hailSunny", "hailThunder", "hailThunderNight", "hailThunderSunny", "halloweenPumpkin", "hammer", "hammerAlt", "hand", "handDown", "handDrag", "handDrag1", "handDrag2", "handDrawnAltDown", "handDrawnAltLeft", "handDrawnAltRight", "handDrawnAltUp", "handDrawnDown", "handDrawnLeft", "handDrawnRight", "handDrawnUp", "handGrippers", "handLeft", "handPower", "handRight", "handThunder", "handUp", "handcuff", "handcuffAlt", "hanger", "hardDisk", "hat", "hatAlt", "header", "headphone", "headphoneAlt", "headphoneAlt1", "headphoneAlt2", "headphoneAlt3", "heart", "heartAlt", "heartBeat", "heartBeatAlt", "heartbeat", "helicopter", "helmet", "helpRobot", "herbal", "hill", "hillNight", "hillSide", "hillSunny", "history", "hockey", "hockeyAlt", "holdingHands", "home", "homeSearch", "honey", "horn", "hospital", "hotDog", "hotel", "hotelAlt", "hotelBoy", "hotelBoyAlt", "hourGlass", "htcOne", "hurricane", "iceCream", "iceCreamAlt", "iceSkate", "icu", "id", "idCard", "idea", "imac", "image", "inbox", "indent", "industries", "industriesAlt1", "industriesAlt2", "industriesAlt3", "industriesAlt4", "industriesAlt5", "infantNipple", "infinite", "info", "infoCircle", "infoSquare", "injectionSyringe", "institution", "instrument", "interface", "investigation", "investigator", "invisible", "ipadTouch", "iphone", "ipodNano", "ipodTouch", "island", "islandAlt", "italic", "italicAlt", "jacket", "jail", "jar", "jcb", "jcbAlt", "jersey", "jerseyAlt", "jewlery", "jobSearch", "judge", "jumping", "justifyAll", "justifyCenter", "justifyLeft", "justifyRight", "karate", "ketchup", "key", "keyHole", "keyboard", "keyboardAlt", "keyboardWireless", "kick", "kid", "kidsScooter", "kingCrown", "kingMonster", "kiwi", "label", "laboratory", "labour", "lamp", "lampLight", "laptop", "laptopAlt", "law", "lawAlt1", "lawAlt2", "lawAlt3", "lawBook", "lawDocument", "lawyer", "lawyerAlt1", "lawyerAlt2", "layeredCake", "layers", "layout", "leaf", "leaflet", "learn", "leg", "legal", "lego", "lemon", "lemonAlt", "lens", "letter", "letterbox", "library", "license", "lifeBouy", "lifeBuoy", "lifeJacket", "lifeRing", "lightBulb", "lighter", "lightningRay", "like", "lineBlockDown", "lineBlockLeft", "lineBlockRight", "lineBlockUp", "lineHeight", "link", "linkAlt", "list", "listening", "listineDots", "listingBox", "listingNumber", "liveSupport", "lobster", "locationArrow", "locationPin", "lock", "login", "logout", "lollipop", "longArrowDown", "longArrowLeft", "longArrowRight", "longArrowUp", "longDrive", "look", "loop", "love", "luggage", "lunch", "lungs", "macbook", "maestro", "maestroAlt", "magic", "magicAlt", "magicMouse", "magicianHat", "magnet", "mail", "mailBox", "male", "manInGlasses", "mango", "map", "mapPins", "mapSearch", "marker", "markerAlt1", "markerAlt2", "markerAlt3", "mastercard", "mastercardAlt", "matchReview", "math", "mathematical", "mathematicalAlt1", "mathematicalAlt2", "maximize", "measure", "medal", "medalAlt", "medical", "medicalSign", "medicalSignAlt", "medicine", "meetingAdd", "megaPhone", "megaphone", "megaphoneAlt", "memorial", "memoryCard", "meteor", "mic", "micMute", "microChip", "microphone", "microphoneAlt", "microscope", "microscopeAlt", "military", "milk", "mill", "mining", "minus", "minusCircle", "minusSquare", "mobilePhone", "molecule", "money", "moneyBag", "monitor", "moon", "mop", "motorBike", "motorBikeAlt", "motorBiker", "mouse", "movie", "mp3Player", "muffin", "multimedia", "muscle", "muscleAlt", "mushroom", "music", "musicAlt", "musicDisk", "musicNote", "musicNotes", "mustache", "muteVolume", "nativeAmerican", "navigation", "navigationMenu", "network", "networkTower", "news", "newspaper", "night", "nintendo", "noSmoking", "noodles", "notAllowed", "notebook", "notepad", "notification", "numbered", "nurse", "nurseAlt", "nursingHome", "offside", "oilTruck", "olympic", "olympicLogo", "onion", "openEye", "operationTheater", "opposite", "optic", "options", "orange", "order", "outdent", "owlLook", "package", "padding", "page", "paint", "paintBrush", "paper", "paperClip", "paperPlane", "paperclip", "papers", "paragraph", "paralysisDisability", "pause", "paw", "pay", "payoneer", "payoneerAlt", "paypal", "paypalAlt", "pear", "peas", "pen", "penAlt1", "penAlt2", "penAlt3", "penAlt4", "penHolder", "penHolderAlt1", "penNib", "penaltyCard", "pencil", "pencilAlt1", "pencilAlt2", "pencilAlt3", "pencilAlt4", "pencilAlt5", "penguinLinux", "people", "pepper", "pestle", "phoenix", "phone", "phoneCircle", "picture", "pie", "pieAlt", "pieChart", "pills", "pin", "pine", "pineapple", "pistol", "pixels", "pizza", "pizzaSlice", "planeTicket", "plant", "play", "playAlt1", "playAlt2", "playAlt3", "playPause", "playstation", "plugin", "plus", "plusCircle", "plusSquare", "police", "policeBadge", "policeCap", "policeCar", "policeCarAlt1", "policeCarAlt2", "policeHat", "policeVan", "pollution", "polygonal", "popcorn", "potato", "power", "powerZone", "prescription", "presentation", "presentationAlt", "price", "print", "printer", "protect", "psvita", "pulse", "pumpkin", "puzzle", "qrCode", "queen", "queenCrown", "question", "questionCircle", "questionSquare", "quillPen", "quoteLeft", "quoteRight", "racer", "racingCar", "racingFlag", "racingFlagAlt", "racingsWheel", "raddish", "radio", "radioActive", "radioMic", "rainy", "rainyNight", "rainySunny", "rainyThunder", "random", "readBook", "readBookAlt", "record", "recycle", "recycleAlt", "recyclingMan", "redo", "referee", "refreeJersey", "refresh", "refrigerator", "repair", "reply", "replyAll", "resize", "responsive", "restaurant", "restaurantMenu", "restaurantSearch", "result", "retroMusicDisk", "retweet", "rewind", "rickshaw", "road", "robot", "robotFace", "rocket", "rocketAlt1", "rocketAlt2", "rotation", "roundedCollapse", "roundedDoubleLeft", "roundedDoubleRight", "roundedDown", "roundedExpand", "roundedLeft", "roundedLeftDown", "roundedLeftUp", "roundedRight", "roundedRightDown", "roundedRightUp", "roundedUp", "royal", "rssFeed", "rugby", "rugbyBall", "rugbyPlayer", "ruler", "rulerAlt1", "rulerAlt2", "rulerCompass", "rulerCompassAlt", "rulerPencil", "rulerPencilAlt1", "rulerPencilAlt2", "rulers", "rulersAlt", "runner", "runnerAlt1", "runnerAlt2", "safety", "safetyHat", "safetyHatLight", "safetyPin", "sage", "sageAlt", "sailBoat", "sailBoatAlt1", "sailBoatAlt2", "saleDiscount", "saltAndPepper", "samsungGalaxy", "sandClock", "sandalsFemale", "sandalsMale", "sandwich", "satellite", "sausage", "save", "saw", "scales", "schoolBag", "schoolBus", "scooter", "scoreBoard", "screwDriver", "scrollBubbleDown", "scrollBubbleLeft", "scrollBubbleRight", "scrollBubbleUp", "scrollDoubleDown", "scrollDoubleLeft", "scrollDoubleRight", "scrollDoubleUp", "scrollDown", "scrollLeft", "scrollLongDown", "scrollLongLeft", "scrollLongRight", "scrollLongUp", "scrollRight", "scrollUp", "seaPlane", "search", "searchAlt1", "searchAlt2", "sendMail", "server", "settings", "settingsAlt", "share", "shareAlt", "shareBoxed", "shield", "shieldAlt", "ship", "shipAlt", "shipWheel", "shoppingCart", "showyNightHail", "shrimp", "signIn", "signOut", "signal", "simpleDown", "simpleLeft", "simpleLeftDown", "simpleLeftUp", "simpleRight", "simpleRightDown", "simpleRightUp", "simpleUp", "siteMap", "skiingMan", "skrill", "skrillAlt", "skullDanger", "skullFace", "skydivingGoggles", "smallCap", "smartPhone", "snail", "snow", "snowAlt", "snowFlake", "snowMobile", "snowTemp", "snowmobile", "snowy", "snowyHail", "snowyNight", "snowyNightRainy", "snowyRainy", "snowySunny", "snowySunnyHail", "snowySunnyRainy", "snowyThunder", "snowyThunderNight", "snowyThunderSunny", "snowyWindy", "snowyWindyNight", "snowyWindySunny", "soccer", "social500px", "socialAim", "socialBadoo", "socialBaiduTieba", "socialBbmMessenger", "socialBebo", "socialBehance", "socialBlogger", "socialBootstrap", "socialBrightkite", "socialCloudapp", "socialConcrete5", "socialDelicious", "socialDesignbump", "socialDesignfloat", "socialDeviantart", "socialDigg", "socialDotcms", "socialDribbble", "socialDribble", "socialDropbox", "socialEbuddy", "socialEllo", "socialEmber", "socialEnvato", "socialEvernote", "socialFacebook", "socialFacebookMessenger", "socialFeedburner", "socialFlikr", "socialFolkd", "socialFoursquare", "socialFriendfeed", "socialGhost", "socialGithub", "socialGnome", "socialGoogleBuzz", "socialGoogleHangouts", "socialGoogleMap", "socialGooglePlus", "socialGoogleTalk", "socialHypeMachine", "socialInstagram", "socialKakaotalk", "socialKickstarter", "socialKik", "socialKiwibox", "socialLine", "socialLinkedin", "socialLinuxMint", "socialLivejournal", "socialMagento", "socialMeetme", "socialMeetup", "socialMixx", "socialNewsvine", "socialNimbuss", "socialOdnoklassniki", "socialOpencart", "socialOscommerce", "socialPandora", "socialPhotobucket", "socialPicasa", "socialPinterest", "socialPrestashop", "socialQik", "socialQq", "socialReadernaut", "socialReddit", "socialRenren", "socialRss", "socialShopify", "socialSilverstripe", "socialSkype", "socialSlack", "socialSlashdot", "socialSlidshare", "socialSmugmug", "socialSnapchat", "socialSoundcloud", "socialSpotify", "socialStackExchange", "socialStackOverflow", "socialSteam", "socialStumbleupon", "socialTagged", "socialTechnorati", "socialTelegram", "socialTinder", "socialTrello", "socialTumblr", "socialTwitch", "socialTwitter", "socialTypo3", "socialUbercart", "socialViber", "socialViddler", "socialVimeo", "socialVine", "socialVirb", "socialVirtuemart", "socialVk", "socialWechat", "socialWeibo", "socialWhatsapp", "socialXing", "socialYahoo", "socialYelp", "socialYouku", "socialYoutube", "socialYoutubePlay", "socialZencart", "sofDrinks", "songNotes", "sort", "sortAlt", "soundWave", "soundWaveAlt", "soupBowl", "space", "spaceShuttle", "spanner", "speechComments", "speedBoat", "speedMeter", "spinner", "spinnerAlt1", "spinnerAlt2", "spinnerAlt3", "spinnerAlt4", "spinnerAlt5", "spinnerAlt6", "spoonAndFork", "spreadsheet", "square", "squareDown", "squareLeft", "squareRight", "squareRoot", "squareUp", "sslSecurity", "stamp", "star", "starAlt1", "starAlt2", "starShape", "steak", "steering", "stethoscope", "stethoscopeAlt", "stockMobile", "stockSearch", "stop", "strawberry", "streetView", "stretcher", "strikeThrough", "stripe", "stripeAlt", "student", "studentAlt", "stylishDown", "stylishLeft", "stylishRight", "stylishUp", "subListing", "subSandwich", "subscripts", "substitute", "sun", "sunAlt", "sunRise", "sunSet", "sunny", "sunnyDayTemp", "superscript", "support", "supportFaq", "surfaceTablet", "surgeon", "surgeonAlt", "sushi", "swimmer", "swirl", "swooshDown", "swooshLeft", "swooshRight", "swooshUp", "table", "tableTennis", "tablets", "tackPin", "taco", "tag", "tags", "tasks", "tasksAlt", "tattooWing", "taxi", "tea", "teaPot", "teacher", "team", "teamAlt", "teddyBear", "telephone", "telescope", "tennis", "tennisPlayer", "terminal", "testBottle", "testBulb", "testTube", "testTubeAlt", "textHeight", "textWidth", "thermometer", "thermometerAlt", "thief", "thiefAlt", "thinDoubleLeft", "thinDoubleRight", "thinDown", "thinLeft", "thinRight", "thinUp", "thinderLight", "throne", "thumbsDown", "thumbsUp", "tickBoxed", "tickMark", "ticket", "tie", "time", "toggleOff", "toggleOn", "tomato", "tools", "toolsAlt1", "toolsAlt2", "toolsBag", "tooth", "tornado", "touch", "towTruck", "toyBall", "toyCat", "toyDuck", "toyElephant", "toyHand", "toyHorse", "toyLattu", "toyTrain", "track", "tracking", "tractor", "trafficLight", "trainLine", "trainSteam", "tram", "transparent", "trash", "travelling", "tree", "treeAlt", "triangle", "trolley", "trophy", "trophyAlt", "trowel", "truck", "truckAlt", "truckLoaded", "uiAdd", "uiAlarm", "uiBattery", "uiBlock", "uiBluetooth", "uiBrightness", "uiBrowser", "uiCalculator", "uiCalendar", "uiCall", "uiCamera", "uiCart", "uiCellPhone", "uiChat", "uiCheck", "uiClip", "uiClipBoard", "uiClock", "uiClose", "uiContactList", "uiCopy", "uiCut", "uiDelete", "uiDialPhone", "uiEdit", "uiEmail", "uiFile", "uiFireWall", "uiFlashLight", "uiFlight", "uiFolder", "uiGame", "uiHandicapped", "uiHeadPhone", "uiHome", "uiImage", "uiKeyboard", "uiLaoding", "uiLock", "uiLove", "uiLoveAdd", "uiLoveBroken", "uiLoveRemove", "uiMap", "uiMessage", "uiMessaging", "uiMovie", "uiMusic", "uiMusicPlayer", "uiMute", "uiNetwork", "uiNext", "uiNote", "uiOffice", "uiPassword", "uiPause", "uiPlay", "uiPlayStop", "uiPointer", "uiPower", "uiPress", "uiPrevious", "uiRateAdd", "uiRateBlank", "uiRateRemove", "uiRating", "uiRecord", "uiRemove", "uiReply", "uiRotation", "uiRss", "uiSearch", "uiSettings", "uiSocialLink", "uiTag", "uiTextChat", "uiTextLoading", "uiTheme", "uiTimer", "uiTouchPhone", "uiTravel", "uiUnlock", "uiUser", "uiUserGroup", "uiVCard", "uiVideo", "uiVideoChat", "uiVideoMessage", "uiVideoPlay", "uiVolume", "uiWeather", "uiWifi", "uiZoomIn", "uiZoomOut", "umbrella", "umbrellaAlt", "underConstruction", "underConstructionAlt", "underline", "undo", "uniqueIdea", "unityHand", "university", "unlink", "unlock", "unlocked", "upload", "uploadAlt", "usb", "usbDrive", "user", "userAlt1", "userAlt2", "userAlt3", "userAlt4", "userAlt5", "userAlt6", "userAlt7", "userFemale", "userMale", "userSearch", "userSuited", "users", "usersAlt1", "usersAlt2", "usersAlt3", "usersAlt4", "usersAlt5", "usersAlt6", "usersSocial", "van", "vanAlt", "vectorPath", "vehicleCement", "vehicleCrane", "vehicleDeliveryVan", "vehicleDozer", "vehicleExcavator", "vehicleTrucktor", "vehicleWrecking", "verificationCheck", "video", "videoAlt", "videoCam", "videoClapper", "visa", "visaAlt", "visaElectron", "volcano", "volleyball", "volleyballAlt", "volleyballFire", "volumeBar", "volumeDown", "volumeMute", "volumeOff", "volumeUp", "waiter", "waiterAlt", "wall", "wallClock", "wallet", "warning", "warningAlt", "washingMachine", "waterBottle", "waterDrop", "watermelon", "wave", "web", "weed", "westernUnion", "westernUnionAlt", "wheat", "wheel", "wheelchair", "whisle", "wifi", "wifiAlt", "wifiRouter", "wiiU", "winTrophy", "wind", "windScale0", "windScale1", "windScale10", "windScale11", "windScale12", "windScale2", "windScale3", "windScale4", "windScale5", "windScale6", "windScale7", "windScale8", "windScale9", "windWaves", "windowsLumia", "windy", "windyHail", "windyNight", "windyRaining", "windySunny", "windyThunder", "windyThunderRaining", "wirelessMouse", "womanBird", "womanInGlasses", "worker", "workerGroup", "world", "wrench", "xbox360", "xray", "yacht", "youtubePlay", "zigzag", "zipped"]
    
    let typIcons = ["AdjustBrightness", "AdjustContrast", "AnchorOutline", "Anchor", "Archive", "ArrowBackOutline", "ArrowBack", "ArrowDownOutline", "ArrowDownThick", "ArrowDown", "ArrowForwardOutline", "ArrowForward", "ArrowLeftOutline", "ArrowLeftThick", "ArrowLeft", "ArrowLoopOutline", "ArrowLoop", "ArrowMaximiseOutline", "ArrowMaximise", "ArrowMinimiseOutline", "ArrowMinimise", "ArrowMoveOutline", "ArrowMove", "ArrowRepeatOutline", "ArrowRepeat", "ArrowRightOutline", "ArrowRightThick", "ArrowRight", "ArrowShuffle", "ArrowSortedDown", "ArrowSortedUp", "ArrowSyncOutline", "ArrowSync", "ArrowUnsorted", "ArrowUpOutline", "ArrowUpThick", "ArrowUp", "At", "AttachmentOutline", "Attachment", "BackspaceOutline", "Backspace", "BatteryCharge", "BatteryFull", "BatteryHigh", "BatteryLow", "BatteryMid", "Beaker", "Beer", "Bell", "Book", "Bookmark", "Briefcase", "Brush", "BusinessCard", "Calculator", "CalendarOutline", "Calendar", "CameraOutline", "Camera", "CancelOutline", "Cancel", "ChartAreaOutline", "ChartArea", "ChartBarOutline", "ChartBar", "ChartLineOutline", "ChartLine", "ChartPieOutline", "ChartPie", "ChevronLeftOutline", "ChevronLeft", "ChevronRightOutline", "ChevronRight", "Clipboard", "CloudStorage", "CloudStorageOutline", "CodeOutline", "Code", "Coffee", "CogOutline", "Cog", "Compass", "Contacts", "CreditCard", "Css3", "Database", "DeleteOutline", "Delete", "DeviceDesktop", "DeviceLaptop", "DevicePhone", "DeviceTablet", "Directions", "DivideOutline", "Divide", "DocumentAdd", "DocumentDelete", "DocumentText", "Document", "DownloadOutline", "Download", "Dropbox", "Edit", "EjectOutline", "Eject", "EqualsOutline", "Equals", "ExportOutline", "Export", "EyeOutline", "Eye", "Feather", "Film", "Filter", "FlagOutline", "Flag", "FlashOutline", "Flash", "FlowChildren", "FlowMerge", "FlowParallel", "FlowSwitch", "FolderAdd", "FolderDelete", "FolderOpen", "Folder", "Gift", "GlobeOutline", "Globe", "GroupOutline", "Group", "Headphones", "HeartFullOutline", "HeartHalfOutline", "HeartOutline", "Heart", "HomeOutline", "Home", "Html5", "ImageOutline", "Image", "InfinityOutline", "Infinity", "InfoLargeOutline", "InfoLarge", "InfoOutline", "Info", "InputCheckedOutline", "InputChecked", "KeyOutline", "Key", "Keyboard", "Leaf", "Lightbulb", "LinkOutline", "Link", "LocationArrowOutline", "LocationArrow", "LocationOutline", "Location", "LockClosedOutline", "LockClosed", "LockOpenOutline", "LockOpen", "Mail", "Map", "MediaEjectOutline", "MediaEject", "MediaFastForwardOutline", "MediaFastForward", "MediaPauseOutline", "MediaPause", "MediaPlayOutline", "MediaPlayReverseOutline", "MediaPlayReverse", "MediaPlay", "MediaRecordOutline", "MediaRecord", "MediaRewindOutline", "MediaRewind", "MediaStopOutline", "MediaStop", "MessageTyping", "Message", "Messages", "MicrophoneOutline", "Microphone", "MinusOutline", "Minus", "MortarBoard", "News", "NotesOutline", "Notes", "Pen", "Pencil", "PhoneOutline", "Phone", "PiOutline", "Pi", "PinOutline", "Pin", "Pipette", "PlaneOutline", "Plane", "Plug", "PlusOutline", "Plus", "PointOfInterestOutline", "PointOfInterest", "PowerOutline", "Power", "Printer", "PuzzleOutline", "Puzzle", "RadarOutline", "Radar", "RefreshOutline", "Refresh", "RssOutline", "Rss", "ScissorsOutline", "Scissors", "ShoppingBag", "ShoppingCart", "SocialAtCircular", "SocialDribbbleCircular", "SocialDribbble", "SocialFacebookCircular", "SocialFacebook", "SocialFlickrCircular", "SocialFlickr", "SocialGithubCircular", "SocialGithub", "SocialGooglePlusCircular", "SocialGooglePlus", "SocialInstagramCircular", "SocialInstagram", "SocialLastFmCircular", "SocialLastFm", "SocialLinkedinCircular", "SocialLinkedin", "SocialPinterestCircular", "SocialPinterest", "SocialSkypeOutline", "SocialSkype", "SocialTumblerCircular", "SocialTumbler", "SocialTwitterCircular", "SocialTwitter", "SocialVimeoCircular", "SocialVimeo", "SocialYoutubeCircular", "SocialYoutube", "SortAlphabeticallyOutline", "SortAlphabetically", "SortNumericallyOutline", "SortNumerically", "SpannerOutline", "Spanner", "Spiral", "StarFullOutline", "StarHalfOutline", "StarHalf", "StarOutline", "Star", "StarburstOutline", "Starburst", "Stopwatch", "Support", "TabsOutline", "Tag", "Tags", "ThLargeOutline", "ThLarge", "ThListOutline", "ThList", "ThMenuOutline", "ThMenu", "ThSmallOutline", "ThSmall", "Thermometer", "ThumbsDown", "ThumbsOk", "ThumbsUp", "TickOutline", "Tick", "Ticket", "Time", "TimesOutline", "Times", "Trash", "Tree", "UploadOutline", "Upload", "UserAddOutline", "UserAdd", "UserDeleteOutline", "UserDelete", "UserOutline", "User", "VendorAndroid", "VendorApple", "VendorMicrosoft", "VideoOutline", "Video", "VolumeDown", "VolumeMute", "VolumeUp", "Volume", "WarningOutline", "Warning", "Watch", "WavesOutline", "Waves", "WeatherCloudy", "WeatherDownpour", "WeatherNight", "WeatherPartlySunny", "WeatherShower", "WeatherSnow", "WeatherStormy", "WeatherSunny", "WeatherWindyCloudy", "WeatherWindy", "WifiOutline", "Wifi", "Wine", "WorldOutline", "World", "ZoomInOutline", "ZoomIn", "ZoomOutOutline", "ZoomOut", "ZoomOutline", "Zoom"]
}
